/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.bzdz.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.bzdz.entity.BzdzEntity;
import org.springblade.modules.bzdz.excel.BzdzExcel;
import org.springblade.modules.bzdz.service.IBzdzService;
import org.springblade.modules.bzdz.vo.BzdzVO;
import org.springblade.modules.bzdz.vo.RlsqVO;
import org.springblade.modules.bzdz.vo.XzqhVO;
import org.springblade.modules.bzdz.wrapper.BzdzWrapper;
import org.springblade.modules.system.entity.Dept;
import org.springblade.modules.system.entity.UserDept;
import org.springblade.modules.system.service.IDeptService;
import org.springblade.modules.system.vo.MjDeptVO;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 楼栋标准地址 控制器
 *
 * @author BladeX
 * @since 2023-12-22
 */
@Slf4j
@RestController
@AllArgsConstructor
@RequestMapping("blade-bzdz/bzdz")
@Api(value = "楼栋标准地址", tags = "楼栋标准地址接口")
public class BzdzController extends BladeController {

	private final IBzdzService bzdzService;

	private final IDeptService deptService;

	/**
	 * 楼栋标准地址 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入bzdz")
	public R<BzdzVO> detail(BzdzEntity bzdz) {
		BzdzEntity detail = bzdzService.getOne(Condition.getQueryWrapper(bzdz));
		return R.data(BzdzWrapper.build().entityVO(detail));
	}
	/**
	 * 楼栋标准地址 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入bzdz")
	public R<IPage<BzdzVO>> list(@ApiIgnore @RequestParam Map<String, Object> bzdz, Query query) {
		IPage<BzdzEntity> pages = bzdzService.page(Condition.getPage(query), Condition.getQueryWrapper(bzdz, BzdzEntity.class));
		return R.data(BzdzWrapper.build().pageVO(pages));
	}

	/**
	 * 楼栋标准地址 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入bzdz")
	public R page(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		log.info("地址经度：" + params.get("dzjd") + " || 地址纬度：" + params.get("dzwd"));
		IPage<BzdzVO> pages = bzdzService.selectBzdzPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 楼栋标准地址 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入bzdz")
	public R save(@Valid @RequestBody BzdzEntity bzdz) {
		bzdzService.save(bzdz);
		bzdz.setDzbm(bzdz.getSqjcwhdm().toString() + bzdz.getId().toString());
		bzdzService.updateById(bzdz);
		bzdz.setLdMc(bzdz.getXqmc() + bzdz.getLdph() + bzdz.getLdphSuffix());
		return R.data(bzdz);
	}

	/**
	 * 楼栋标准地址 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入bzdz")
	public R update(@Valid @RequestBody BzdzEntity bzdz) {
		return R.status(bzdzService.updateById(bzdz));
	}

	/**
	 * 楼栋标准地址 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入bzdz")
	public R submit(@Valid @RequestBody BzdzEntity bzdz) {
		return R.status(bzdzService.saveOrUpdate(bzdz));
	}

	/**
	 * 楼栋标准地址 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(bzdzService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@GetMapping("/export-bzdz")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入bzdz")
	public void exportBzdz(@ApiIgnore @RequestParam Map<String, Object> bzdz, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<BzdzEntity> queryWrapper = Condition.getQueryWrapper(bzdz, BzdzEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(Bzdz::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(BzdzEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<BzdzExcel> list = bzdzService.exportBzdz(queryWrapper);
		ExcelUtil.export(response, "楼栋标准地址数据" + DateUtil.time(), "楼栋标准地址数据表", list, BzdzExcel.class);
	}

	/**
	 * app-获取行政区划
	 * lb 1=省 2=市 3=区/县 4=街道/乡镇 5=社区/村  parentId
	 */
	@GetMapping("/getXzqh")
	public R getXzqh(@RequestParam Map<String, Object> params) {
		List<XzqhVO> xzqh = bzdzService.getXzqh(params);
		return R.data(xzqh);
	}

	/**
	 * app-获取行政区划
	 * lb 1=省 2=市 3=区/县 4=街道/乡镇 5=社区/村  parentId
	 */
	@GetMapping("/getXzqhPt")
	public R getXzqhPt(@RequestParam Map<String, Object> params) {
		Dept dept = deptService.getById(Long.parseLong(AuthUtil.getDeptId()));
		if (dept.getDeptCategory() == 6 && !dept.getAncestors().contains("229600000000") && !dept.getId().toString().equals("229600000000")){
			Dept fj = deptService.getById(dept.getParentId());
			params.put("qv",dept.getParentId());
			params.put("shi",fj.getParentId());
			if (dept.getParentId() == Long.parseLong("220581010000")){
				params.put("qv","220581000001");
			}
		}
		if (dept.getAncestors().contains("229600000000")){
			params.put("type","1");
		}
		List<RlsqVO> tree = bzdzService.getXzqhPtTree(params);
		/*for (RlsqVO shiTree:tree){
			List<RlsqVO> shi = bzdzService.getShi(params);
			shiTree.setChildren(shi);
			for (RlsqVO qvTree:shi){
				List<RlsqVO> qv = bzdzService.getQv(params);
				qvTree.setChildren(qv);
				for (RlsqVO jdTree:qv){
					List<RlsqVO> jd = bzdzService.getJd(params);
					jdTree.setChildren(jd);
					for (RlsqVO sqTree:jd){
						List<RlsqVO> sq = bzdzService.getSq(params,sqTree.getZddm());
						sqTree.setChildren(sq);
					}
				}
			}
		}*/
		return R.data(tree);
	}

	/**
	 * 民警平台维护部门
	 */
	@Transactional
	@PostMapping("/updateUserDept")
	public R updateUserDept(@RequestBody MjDeptVO params) {
		// 查询社区是否存在，不存在则新增社区
		//int sqNum = deptService.countDeptById(Long.valueOf(sqIdList[i]));
		int sqNum = deptService.getDeptById(params.getId());
		if (sqNum == 0) {
			Dept sq = new Dept();
			Dept dept = deptService.getById(Long.parseLong(AuthUtil.getDeptId()));
			sq.setId(params.getId());
			sq.setTenantId("000000");
			sq.setParentId(Long.parseLong(AuthUtil.getDeptId()));
			sq.setAncestors(dept.getAncestors() + "," + dept.getId().toString());
			sq.setDeptCategory(7);
			sq.setDeptName(params.getDeptName());
			sq.setFullName(params.getDeptName());
			sq.setSort(1);
			sq.setIsDeleted(0);
			deptService.save(sq);
		} else {
			// 所选社区的归属派出所
			//Dept dept = deptService.getParentDept(sqIdList[i]);
			Dept dept = deptService.getParentDept(params.getId().toString());
			if (null != dept && null != dept.getId() && !dept.getId().equals(params.getId())) {
				return R.fail(params.getDeptName() + " 已被 " + dept.getDeptName() + " 认领，请联系管理员");
			}
		}
		return R.success("认领成功");
	}
}
