/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.fjInfo.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.fjInfo.entity.FjInfoEntity;
import org.springblade.modules.fjInfo.vo.FjInfoVO;
import org.springblade.modules.fjInfo.excel.FjInfoExcel;
import org.springblade.modules.fjInfo.wrapper.FjInfoWrapper;
import org.springblade.modules.fjInfo.service.IFjInfoService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 辅警管理 控制器
 *
 * @author BladeX
 * @since 2024-03-18
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-fjInfo/fjInfo")
@Api(value = "辅警管理", tags = "辅警管理接口")
public class FjInfoController extends BladeController {

	private final IFjInfoService fjInfoService;

	/**
	 * 辅警管理 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入fjInfo")
	public R<FjInfoVO> detail(FjInfoEntity fjInfo) {
		FjInfoEntity detail = fjInfoService.getOne(Condition.getQueryWrapper(fjInfo));
		return R.data(FjInfoWrapper.build().entityVO(detail));
	}
	/**
	 * 辅警管理 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入fjInfo")
	public R<IPage<FjInfoVO>> list(@ApiIgnore @RequestParam Map<String, Object> fjInfo, Query query) {
		IPage<FjInfoEntity> pages = fjInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(fjInfo, FjInfoEntity.class));
		return R.data(FjInfoWrapper.build().pageVO(pages));
	}

	/**
	 * 辅警管理 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入fjInfo")
	public R<IPage<FjInfoVO>> page(FjInfoVO fjInfo, Query query) {
		IPage<FjInfoVO> pages = fjInfoService.selectFjInfoPage(Condition.getPage(query), fjInfo);
		return R.data(pages);
	}

	/**
	 * 辅警管理 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入fjInfo")
	public R save(@Valid @RequestBody FjInfoEntity fjInfo) {
		return R.status(fjInfoService.save(fjInfo));
	}

	/**
	 * 辅警管理 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入fjInfo")
	public R update(@Valid @RequestBody FjInfoEntity fjInfo) {
		return R.status(fjInfoService.updateById(fjInfo));
	}

	/**
	 * 辅警管理 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入fjInfo")
	public R submit(@Valid @RequestBody FjInfoEntity fjInfo) {
		return R.status(fjInfoService.saveOrUpdate(fjInfo));
	}

	/**
	 * 辅警管理 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(fjInfoService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-fjInfo")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入fjInfo")
	public void exportFjInfo(@ApiIgnore @RequestParam Map<String, Object> fjInfo, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<FjInfoEntity> queryWrapper = Condition.getQueryWrapper(fjInfo, FjInfoEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(FjInfo::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(FjInfoEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<FjInfoExcel> list = fjInfoService.exportFjInfo(queryWrapper);
		ExcelUtil.export(response, "辅警管理数据" + DateUtil.time(), "辅警管理数据表", list, FjInfoExcel.class);
	}

}
