/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.fwbzdz.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.fwbzdz.entity.fwBzdzEntity;
import org.springblade.modules.fwbzdz.excel.fwBzdzExcel;
import org.springblade.modules.fwbzdz.service.IfwBzdzService;
import org.springblade.modules.fwbzdz.vo.fwBzdzVO;
import org.springblade.modules.fwbzdz.wrapper.fwBzdzWrapper;
import org.springblade.modules.system.entity.Bzdz;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 标准地址 控制器
 *
 * @author BladeX
 * @since 2023-12-17
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-fwbzdz/fwbzdz")
@Api(value = "标准地址", tags = "标准地址接口")
public class fwBzdzController extends BladeController {

	private final IfwBzdzService fwbzdzService;

	/**
	 * 标准地址 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入fwbzdz")
	public R<fwBzdzVO> detail(fwBzdzEntity fwbzdz) {
		fwBzdzEntity detail = fwbzdzService.getOne(Condition.getQueryWrapper(fwbzdz));
		return R.data(fwBzdzWrapper.build().entityVO(detail));
	}
	/**
	 * 标准地址 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入fwbzdz")
	public R<IPage<fwBzdzVO>> list(@ApiIgnore @RequestParam Map<String, Object> fwbzdz, Query query) {
		IPage<fwBzdzEntity> pages = fwbzdzService.page(Condition.getPage(query), Condition.getQueryWrapper(fwbzdz, fwBzdzEntity.class));
		return R.data(fwBzdzWrapper.build().pageVO(pages));
	}

	/**
	 * 标准地址 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入fwbzdz")
	public R<IPage<Bzdz>> page(Bzdz fwbzdz, Query query) {
		IPage<Bzdz> pages = fwbzdzService.selectfwBzdzPage(Condition.getPage(query), fwbzdz);
		return R.data(pages);
	}

	/**
	 * 标准地址 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入fwbzdz")
	public R save(@Valid @RequestBody fwBzdzEntity fwbzdz) {
		return R.status(fwbzdzService.save(fwbzdz));
	}

	/**
	 * 标准地址 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入fwbzdz")
	public R update(@Valid @RequestBody fwBzdzEntity fwbzdz) {
		return R.status(fwbzdzService.updateById(fwbzdz));
	}

	/**
	 * 标准地址 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入fwbzdz")
	public R submit(@Valid @RequestBody fwBzdzEntity fwbzdz) {
		return R.status(fwbzdzService.saveOrUpdate(fwbzdz));
	}

	/**
	 * 标准地址 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(fwbzdzService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-fwbzdz")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入fwbzdz")
	public void exportfwBzdz(@ApiIgnore @RequestParam Map<String, Object> fwbzdz, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<fwBzdzEntity> queryWrapper = Condition.getQueryWrapper(fwbzdz, fwBzdzEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(fwBzdz::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(fwBzdzEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<fwBzdzExcel> list = fwbzdzService.exportfwBzdz(queryWrapper);
		ExcelUtil.export(response, "标准地址数据" + DateUtil.time(), "标准地址数据表", list, fwBzdzExcel.class);
	}

}
