/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.infoSb.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.infoSb.entity.InfoSbEntity;
import org.springblade.modules.infoSb.vo.InfoSbVO;
import org.springblade.modules.infoSb.excel.InfoSbExcel;
import org.springblade.modules.infoSb.wrapper.InfoSbWrapper;
import org.springblade.modules.infoSb.service.IInfoSbService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 场所上报 控制器
 *
 * @author BladeX
 * @since 2024-03-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-infoSb/infoSb")
@Api(value = "场所上报", tags = "场所上报接口")
public class InfoSbController extends BladeController {

	private final IInfoSbService infoSbService;

	/**
	 * 场所上报 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入infoSb")
	public R<InfoSbVO> detail(InfoSbEntity infoSb) {
		InfoSbEntity detail = infoSbService.getOne(Condition.getQueryWrapper(infoSb));
		return R.data(InfoSbWrapper.build().entityVO(detail));
	}
	/**
	 * 场所上报 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入infoSb")
	public R<IPage<InfoSbVO>> list(@ApiIgnore @RequestParam Map<String, Object> infoSb, Query query) {
		IPage<InfoSbEntity> pages = infoSbService.page(Condition.getPage(query), Condition.getQueryWrapper(infoSb, InfoSbEntity.class));
		return R.data(InfoSbWrapper.build().pageVO(pages));
	}

	/**
	 * 场所上报 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入infoSb")
	public R<IPage<InfoSbVO>> page(InfoSbVO infoSb, Query query) {
		IPage<InfoSbVO> pages = infoSbService.selectInfoSbPage(Condition.getPage(query), infoSb);
		return R.data(pages);
	}

	/**
	 * 场所上报 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入infoSb")
	public R save(@Valid @RequestBody InfoSbEntity infoSb) {
		return R.status(infoSbService.save(infoSb));
	}

	/**
	 * 场所上报 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入infoSb")
	public R update(@Valid @RequestBody InfoSbEntity infoSb) {
		return R.status(infoSbService.updateById(infoSb));
	}

	/**
	 * 场所上报 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入infoSb")
	public R submit(@Valid @RequestBody InfoSbEntity infoSb) {
		return R.status(infoSbService.saveOrUpdate(infoSb));
	}

	/**
	 * 场所上报 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(infoSbService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-infoSb")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入infoSb")
	public void exportInfoSb(@ApiIgnore @RequestParam Map<String, Object> infoSb, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<InfoSbEntity> queryWrapper = Condition.getQueryWrapper(infoSb, InfoSbEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(InfoSb::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(InfoSbEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<InfoSbExcel> list = infoSbService.exportInfoSb(queryWrapper);
		ExcelUtil.export(response, "场所上报数据" + DateUtil.time(), "场所上报数据表", list, InfoSbExcel.class);
	}

}
