/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.jjdb.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.jjdb.entity.JjdbEntity;
import org.springblade.modules.jjdb.service.IJjdbService;
import org.springblade.modules.jjdb.vo.JjdbVO;
import org.springblade.modules.jjdb.wrapper.JjdbWrapper;
import org.springblade.modules.mdjfdj.service.IMdjfDjService;
import org.springblade.modules.mdjftj.service.IMdjfTjService;
import org.springblade.modules.system.vo.SqVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.validation.Valid;
import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * 接警处置 控制器
 *
 * @author ldx
 * @since 2023-09-08
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-jjdb/jjdb")
@Api(value = "接警处置", tags = "接警处置接口")
public class JjdbController extends BladeController {

	private final IJjdbService jjdbService;

	@Autowired
	IMdjfDjService mdjfDjService;

	@Autowired
	IMdjfTjService mdjfTjService;
	/**
	 * 接警处置 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入jjdb")
	public R<JjdbEntity> detail(JjdbEntity jjdb) {
		JjdbEntity detail = jjdbService.getDetail(jjdb.getSjdbh());
		if("92".equals(detail.getBjlbdm())){
			detail.setBjlbdm("纠纷");
		}
		return R.data(detail);
	}
	/**
	 * 接警处置 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入jjdb")
	public R<IPage<JjdbVO>> list(@ApiIgnore @RequestParam Map<String, Object> jjdb, Query query) {
		jjdb.put("bjlbdm","92");
		IPage<JjdbEntity> pages = jjdbService.page(Condition.getPage(query), Condition.getQueryWrapper(jjdb, JjdbEntity.class));
		return R.data(JjdbWrapper.build().pageVO(pages));
	}

	/**
	 * 接警处置 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入jjdb")
	public R<IPage<JjdbVO>> page(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		IPage<JjdbVO> pages = jjdbService.selectJjdbPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 处置时选择社区
	 */
	@GetMapping("/getSq")
	public R getSq(@RequestParam Map<String, Object> params) {
		params.put("deptId", AuthUtil.getDeptId());
		List<SqVO> sqList = jjdbService.getSq(params);
		return R.data(sqList);
	}

	/**
	 * 接警处置 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入jjdb")
	public R save(@Valid @RequestBody JjdbEntity jjdb) {
		return R.status(jjdbService.save(jjdb));
	}



	/**
	 * 接警处置 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入jjdb")
	public R update(@Valid @RequestBody JjdbEntity jjdb) throws ParseException {
		jjdbService.czJjdb(jjdb);
		return R.status(true);
	}

	/**
	 * 接警处置 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入jjdb")
	public R submit(@Valid @RequestBody JjdbEntity jjdb) {
		return R.status(jjdbService.saveOrUpdate(jjdb));
	}

	/**
	 * 接警处置 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jjdbService.deleteLogic(Func.toLongList(ids)));
	}


//	/**
//	 * 导出数据
//	 */
//	@GetMapping("/export-jjdb")
//	@ApiOperationSupport(order = 9)
//	@ApiOperation(value = "导出数据", notes = "传入jjdb")
//	public void exportJjdb(@ApiIgnore @RequestParam Map<String, Object> jjdb, BladeUser bladeUser, HttpServletResponse response) {
//		QueryWrapper<JjdbEntity> queryWrapper = Condition.getQueryWrapper(jjdb, JjdbEntity.class);
//		//if (!AuthUtil.isAdministrator()) {
//		//	queryWrapper.lambda().eq(Jjdb::getTenantId, bladeUser.getTenantId());
//		//}
//		queryWrapper.lambda().eq(JjdbEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
//		List<JjdbExcel> list = jjdbService.exportJjdb(queryWrapper);
//		ExcelUtil.export(response, "接警处置数据" + DateUtil.time(), "接警处置数据表", list, JjdbExcel.class);
//	}

}
