/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.jyxpgxb.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.jyxpgxb.entity.JyxpgxbEntity;
import org.springblade.modules.jyxpgxb.vo.JyxpgxbVO;
import org.springblade.modules.jyxpgxb.excel.JyxpgxbExcel;
import org.springblade.modules.jyxpgxb.wrapper.JyxpgxbWrapper;
import org.springblade.modules.jyxpgxb.service.IJyxpgxbService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 警员下派关系表 控制器
 *
 * @author BladeX
 * @since 2023-07-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-jyxpgxb/Jyxpgxb")
@Api(value = "警员下派关系表", tags = "警员下派关系表接口")
public class JyxpgxbController extends BladeController {

	private final IJyxpgxbService JyxpgxbService;
	private final IUserService userService;
	/**
	 * 警员下派关系表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入Jyxpgxb")
	public R<JyxpgxbVO> detail(JyxpgxbEntity Jyxpgxb) {
		JyxpgxbEntity detail = JyxpgxbService.getOne(Condition.getQueryWrapper(Jyxpgxb));
		return R.data(JyxpgxbWrapper.build().entityVO(detail));
	}
	/**
	 * 警员下派关系表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入Jyxpgxb")
	public R<IPage<JyxpgxbVO>> list(@ApiIgnore @RequestParam Map<String, Object> Jyxpgxb, Query query) {
		IPage<JyxpgxbEntity> pages = JyxpgxbService.page(Condition.getPage(query), Condition.getQueryWrapper(Jyxpgxb, JyxpgxbEntity.class));
		return R.data(JyxpgxbWrapper.build().pageVO(pages));
	}

	/**
	 * 警员下派关系表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入Jyxpgxb")
	public R<IPage<JyxpgxbVO>> page(JyxpgxbVO Jyxpgxb, Query query) {
		IPage<JyxpgxbVO> pages = JyxpgxbService.selectJyxpgxbPage(Condition.getPage(query), Jyxpgxb);
		return R.data(pages);
	}

	/**
	 * 警员下派关系表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入Jyxpgxb")
	public R save(@Valid @RequestBody JyxpgxbEntity Jyxpgxb) {
		return R.status(JyxpgxbService.save(Jyxpgxb));
	}

	/**
	 * 警员下派关系表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入Jyxpgxb")
	public R update(@Valid @RequestBody JyxpgxbEntity Jyxpgxb) {
		return R.status(JyxpgxbService.updateById(Jyxpgxb));
	}

	/**
	 * 警员下派关系表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入Jyxpgxb")
	public R submit(@Valid @RequestBody JyxpgxbEntity Jyxpgxb) {
		return R.status(JyxpgxbService.saveOrUpdate(Jyxpgxb));
	}

	/**
	 * 警员下派关系表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(JyxpgxbService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-Jyxpgxb")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入Jyxpgxb")
	public void exportJyxpgxb(@ApiIgnore @RequestParam Map<String, Object> Jyxpgxb, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JyxpgxbEntity> queryWrapper = Condition.getQueryWrapper(Jyxpgxb, JyxpgxbEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(Jyxpgxb::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(JyxpgxbEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JyxpgxbExcel> list = JyxpgxbService.exportJyxpgxb(queryWrapper);
		ExcelUtil.export(response, "警员下派关系表数据" + DateUtil.time(), "警员下派关系表数据表", list, JyxpgxbExcel.class);
	}


	/**
	 * 下派
	 */
	@PostMapping("/xiapai")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入Jyxpgxb")
	public R xiapai(@Valid @RequestBody JyxpgxbEntity Jyxpgxb) {
		User user = new User();
		user.setId(Jyxpgxb.getXpmjid());
		user.setStatus(0);
		userService.updateById(user);
		return R.status(JyxpgxbService.saveOrUpdate(Jyxpgxb));
	}


}
