/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.khsdPcs.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.khsdPcs.entity.KhsdPcsEntity;
import org.springblade.modules.khsdPcs.vo.KhsdPcsVO;
import org.springblade.modules.khsdPcs.excel.KhsdPcsExcel;
import org.springblade.modules.khsdPcs.wrapper.KhsdPcsWrapper;
import org.springblade.modules.khsdPcs.service.IKhsdPcsService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 考核设定--派出所 控制器
 *
 * @author BladeX
 * @since 2023-07-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-khsdPcs/khsdPcs")
@Api(value = "考核设定--派出所", tags = "考核设定--派出所接口")
public class KhsdPcsController extends BladeController {

	private final IKhsdPcsService khsdPcsService;

	/**
	 * 考核设定--派出所 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入khsdPcs")
	public R detail(@RequestParam Map<String, Object> params) {
		if (null != params.get("yf")) {
			String yf = params.get("yf").toString();
			params.put("yf", yf.substring(0, 7));
		}
		KhsdPcsEntity khcs = khsdPcsService.getDetail(params);
		return R.data(khcs);
	}
	/**
	 * 考核设定--派出所 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入khsdPcs")
	public R<IPage<KhsdPcsVO>> list(@ApiIgnore @RequestParam Map<String, Object> khsdPcs, Query query) {
		IPage<KhsdPcsEntity> pages = khsdPcsService.page(Condition.getPage(query), Condition.getQueryWrapper(khsdPcs, KhsdPcsEntity.class));
		return R.data(KhsdPcsWrapper.build().pageVO(pages));
	}

	/**
	 * 考核设定--派出所 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入khsdPcs")
	public R<IPage<KhsdPcsVO>> page(KhsdPcsVO khsdPcs, Query query) {
		IPage<KhsdPcsVO> pages = khsdPcsService.selectKhsdPcsPage(Condition.getPage(query), khsdPcs);
		return R.data(pages);
	}

	/**
	 * 考核设定--派出所 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入khsdPcs")
	public R save(@Valid @RequestBody KhsdPcsEntity khsdPcs) {
		return R.status(khsdPcsService.save(khsdPcs));
	}

	/**
	 * 考核设定--派出所 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入khsdPcs")
	public R update(@Valid @RequestBody KhsdPcsEntity khsdPcs) {
		return R.status(khsdPcsService.updateById(khsdPcs));
	}

	/**
	 * 考核设定--派出所 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入khsdPcs")
	public R submit(@Valid @RequestBody KhsdPcsEntity khsdPcs) {
		if (null != khsdPcs.getKhyf()) {
			String yf = khsdPcs.getKhyf();
			khsdPcs.setKhyf(khsdPcs.getKhyf().substring(0, 7));
		}
		return R.status(khsdPcsService.saveOrUpdate(khsdPcs));
	}

	/**
	 * 考核设定--派出所 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(khsdPcsService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-khsdPcs")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入khsdPcs")
	public void exportKhsdPcs(@ApiIgnore @RequestParam Map<String, Object> khsdPcs, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<KhsdPcsEntity> queryWrapper = Condition.getQueryWrapper(khsdPcs, KhsdPcsEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(KhsdPcs::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(KhsdPcsEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<KhsdPcsExcel> list = khsdPcsService.exportKhsdPcs(queryWrapper);
		ExcelUtil.export(response, "考核设定--派出所数据" + DateUtil.time(), "考核设定--派出所数据表", list, KhsdPcsExcel.class);
	}

}
