/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.khsdtyb.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import liquibase.pro.packaged.Q;
import lombok.AllArgsConstructor;

import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.khsdPcs.entity.KhsdPcsEntity;
import org.springblade.modules.khsdPcs.service.IKhsdPcsService;
import org.springblade.modules.system.entity.Dept;
import org.springblade.modules.system.service.IDeptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.khsdtyb.entity.KhsdtybEntity;
import org.springblade.modules.khsdtyb.vo.KhsdtybVO;
import org.springblade.modules.khsdtyb.excel.KhsdtybExcel;
import org.springblade.modules.khsdtyb.wrapper.KhsdtybWrapper;
import org.springblade.modules.khsdtyb.service.IKhsdtybService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;

import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 考核设定-底表 控制器
 *
 * @author BladeX
 * @since 2023-07-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-khsdtyb/khsdtyb")
@Api(value = "考核设定-底表", tags = "考核设定-底表接口")
public class KhsdtybController extends BladeController {

	private final IKhsdtybService khsdtybService;
	@Autowired
	IKhsdPcsService khsdPcsService;
	@Autowired
	IDeptService deptService;


	/**
	 * 考核设定-底表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入khsdtyb")
	public R<KhsdtybVO> detail(KhsdtybEntity khsdtyb) {
		KhsdtybEntity detail = khsdtybService.getOne(Condition.getQueryWrapper(khsdtyb));
		return R.data(KhsdtybWrapper.build().entityVO(detail));
	}

	/**
	 * 考核设定-底表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入khsdtyb")
	public R<IPage<KhsdtybVO>> list(@ApiIgnore @RequestParam Map<String, Object> khsdtyb, Query query) {
		IPage<KhsdtybEntity> pages = khsdtybService.page(Condition.getPage(query), Condition.getQueryWrapper(khsdtyb, KhsdtybEntity.class));
		return R.data(KhsdtybWrapper.build().pageVO(pages));
	}

	/**
	 * 考核设定-底表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入khsdtyb")
	public R<IPage<KhsdtybVO>> page(KhsdtybVO khsdtyb, Query query) {
		khsdtyb.setCreateUser(AuthUtil.getUserId());
		IPage<KhsdtybVO> pages = khsdtybService.selectKhsdtybPage(Condition.getPage(query), khsdtyb);
		return R.data(pages);
	}

	/**
	 * 考核设定-底表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入khsdtyb")
	public R save(@Valid @RequestBody KhsdtybEntity khsdtyb) {
		return R.status(khsdtybService.save(khsdtyb));
	}

	/**
	 * 考核设定-底表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入khsdtyb")
	public R update(@Valid @RequestBody KhsdtybEntity khsdtyb) {
		return R.status(khsdtybService.updateById(khsdtyb));
	}

	/**
	 * 考核设定-底表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入khsdtyb")
	public R submit(@Valid @RequestBody KhsdtybEntity khsdtyb) {
		BladeUser user = AuthUtil.getUser();
		boolean b = khsdtybService.saveOrUpdate(khsdtyb);
		Dept byId = deptService.getById(Long.parseLong(user.getDeptId()));
		QueryWrapper<KhsdPcsEntity> qe = new QueryWrapper<>();
		qe.eq("khxid", khsdtyb.getId());
		KhsdPcsEntity khsdPcsEntity = khsdPcsService.getOne(qe);
		if(khsdPcsEntity ==null){
			khsdPcsEntity = new KhsdPcsEntity();
			khsdPcsEntity.setPcsdm(Long.parseLong(user.getDeptId()));
			khsdPcsEntity.setPcsmc(byId.getDeptName());
			khsdPcsEntity.setKhxid(khsdtyb.getId());
		}
		khsdPcsEntity.setKhyf(khsdtyb.getKhmonth());
		khsdPcsEntity.setKhcs(khsdtyb.getKhtimes());
		khsdPcsEntity.setKhfs(khsdtyb.getKhfs());
		khsdPcsEntity.setSjhm(khsdtyb.getSjhm());
		khsdPcsService.saveOrUpdate(khsdPcsEntity);

		return R.status(b);
	}

	/**
	 * 考核设定-底表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		String[] split = ids.split(",");
		if(split.length>1){
			khsdtybService.deleteLogic(Func.toLongList(ids));
		}else{
			QueryWrapper<KhsdtybEntity> qeq = new QueryWrapper<>();
			qeq.eq("id",Long.parseLong(ids));
			qeq.eq("create_user",AuthUtil.getUserId());
			khsdtybService.remove(qeq);
			QueryWrapper<KhsdPcsEntity> qe = new QueryWrapper<>();
			qe.eq("khxid",Long.parseLong(ids));
			khsdPcsService.remove(qe);
		}
		return R.status(true);
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-khsdtyb")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入khsdtyb")
	public void exportKhsdtyb(@ApiIgnore @RequestParam Map<String, Object> khsdtyb, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<KhsdtybEntity> queryWrapper = Condition.getQueryWrapper(khsdtyb, KhsdtybEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(Khsdtyb::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(KhsdtybEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<KhsdtybExcel> list = khsdtybService.exportKhsdtyb(queryWrapper);
		ExcelUtil.export(response, "考核设定-底表数据" + DateUtil.time(), "考核设定-底表数据表", list, KhsdtybExcel.class);
	}

}
