/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.ldInfo.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.ldInfo.entity.LdInfoEntity;
import org.springblade.modules.ldInfo.excel.LdInfoExcel;
import org.springblade.modules.ldInfo.service.ILdInfoService;
import org.springblade.modules.ldInfo.vo.LdInfoVO;
import org.springblade.modules.ldInfo.wrapper.LdInfoWrapper;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 楼栋 控制器
 *
 * @author BladeX
 * @since 2023-07-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-ldInfo/LdInfo")
@Api(value = "楼栋", tags = "楼栋接口")
public class LdInfoController extends BladeController {

	private final ILdInfoService LdInfoService;

	/**
	 * 楼栋 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入LdInfo")
	public R<LdInfoVO> detail(LdInfoEntity LdInfo) {
		LdInfoEntity detail = LdInfoService.getOne(Condition.getQueryWrapper(LdInfo));
		return R.data(LdInfoWrapper.build().entityVO(detail));
	}
	/**
	 * 楼栋 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入LdInfo")
	public R<IPage<LdInfoVO>> list(@ApiIgnore @RequestParam Map<String, Object> params, Query query) {
		IPage<LdInfoEntity> pages = LdInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(params, LdInfoEntity.class));
		return R.data(LdInfoWrapper.build().pageVO(pages));
	}

	/**
	 * 楼栋 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入LdInfo")
	public R<IPage<LdInfoVO>> page(LdInfoVO LdInfo, Query query) {
		IPage<LdInfoVO> pages = LdInfoService.selectLdInfoPage(Condition.getPage(query), LdInfo);
		return R.data(pages);
	}

	/**
	 * 查询没有信息员负责的楼栋
	 */
	@GetMapping("/ldWithNoXxy")
	public R<IPage<LdInfoVO>> page(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		IPage<LdInfoVO> pages = LdInfoService.selectLdWithNoXxy(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 楼栋 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入LdInfo")
	public R save(@Valid @RequestBody LdInfoEntity LdInfo) {
		return R.status(LdInfoService.save(LdInfo));
	}

	/**
	 * 楼栋 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入LdInfo")
	public R update(@Valid @RequestBody LdInfoEntity LdInfo) {
		return R.status(LdInfoService.updateById(LdInfo));
	}

	/**
	 * 楼栋 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入LdInfo")
	public R submit(@Valid @RequestBody LdInfoEntity LdInfo) {
		return R.status(LdInfoService.saveOrUpdate(LdInfo));
	}

	/**
	 * 楼栋 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(LdInfoService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-LdInfo")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入LdInfo")
	public void exportLdInfo(@ApiIgnore @RequestParam Map<String, Object> LdInfo, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<LdInfoEntity> queryWrapper = Condition.getQueryWrapper(LdInfo, LdInfoEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(LdInfo::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(LdInfoEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<LdInfoExcel> list = LdInfoService.exportLdInfo(queryWrapper);
		ExcelUtil.export(response, "楼栋数据" + DateUtil.time(), "楼栋数据表", list, LdInfoExcel.class);
	}

}
