/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.logCsInfo.excel;


import lombok.Data;

import java.util.Date;
import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.ColumnWidth;
import com.alibaba.excel.annotation.write.style.ContentRowHeight;
import com.alibaba.excel.annotation.write.style.HeadRowHeight;
import java.io.Serializable;


/**
 * 日志_九小场所信息变动表 Excel实体类
 *
 * @author BladeX
 * @since 2024-04-17
 */
@Data
@ColumnWidth(25)
@HeadRowHeight(20)
@ContentRowHeight(18)
public class LogCsInfoExcel implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 单位/场所名称
	 */
	@ColumnWidth(20)
	@ExcelProperty("单位/场所名称")
	private String csmc;
	/**
	 * 地址
	 */
	@ColumnWidth(20)
	@ExcelProperty("地址")
	private String dz;
	/**
	 * 单位类别
	 */
	@ColumnWidth(20)
	@ExcelProperty("单位类别")
	private String dwlb;
	/**
	 * 单位细类
	 */
	@ColumnWidth(20)
	@ExcelProperty("单位细类")
	private String dwxl;
	/**
	 * 法定代表人
	 */
	@ColumnWidth(20)
	@ExcelProperty("法定代表人")
	private String fzr;
	/**
	 * 法定代表人电话
	 */
	@ColumnWidth(20)
	@ExcelProperty("法定代表人电话")
	private String fzrDh;
	/**
	 * 消防负责人
	 */
	@ColumnWidth(20)
	@ExcelProperty("消防负责人")
	private String xffzr;
	/**
	 * 消防负责人身份证号
	 */
	@ColumnWidth(20)
	@ExcelProperty("消防负责人身份证号")
	private String xffzrsfzh;
	/**
	 * 消防负责人联系电话
	 */
	@ColumnWidth(20)
	@ExcelProperty("消防负责人联系电话")
	private String xffzrlxdh;
	/**
	 * 房屋类型
	 */
	@ColumnWidth(20)
	@ExcelProperty("房屋类型")
	private String fwlx;
	/**
	 * 使用的建筑面积(㎡)
	 */
	@ColumnWidth(20)
	@ExcelProperty("使用的建筑面积(㎡)")
	private String jzmj;
	/**
	 * 使用的建筑具体层数
	 */
	@ColumnWidth(20)
	@ExcelProperty("使用的建筑具体层数")
	private String jzcs;
	/**
	 * 所在建筑高度(m)
	 */
	@ColumnWidth(20)
	@ExcelProperty("所在建筑高度(m)")
	private String gd;
	/**
	 * 注册资本
	 */
	@ColumnWidth(20)
	@ExcelProperty("注册资本")
	private String zczb;
	/**
	 * 成立日期
	 */
	@ColumnWidth(20)
	@ExcelProperty("成立日期")
	private String clrq;
	/**
	 * 经营期限
	 */
	@ColumnWidth(20)
	@ExcelProperty("经营期限")
	private String jyqx;
	/**
	 * 经营范围
	 */
	@ColumnWidth(20)
	@ExcelProperty("经营范围")
	private String jyfw;
	/**
	 * 工商登记机关
	 */
	@ColumnWidth(20)
	@ExcelProperty("工商登记机关")
	private String djjg;
	/**
	 * 工商登记日期
	 */
	@ColumnWidth(20)
	@ExcelProperty("工商登记日期")
	private String djrq;
	/**
	 * 采集时间
	 */
	@ColumnWidth(20)
	@ExcelProperty("采集时间")
	private String cjsj;
	/**
	 * 采集单位
	 */
	@ColumnWidth(20)
	@ExcelProperty("采集单位")
	private String cjdw;
	/**
	 * 采集人
	 */
	@ColumnWidth(20)
	@ExcelProperty("采集人")
	private String cjr;
	/**
	 * 所属分局编码
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属分局编码")
	private Long ssfjBm;
	/**
	 * 所属分局
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属分局")
	private String ssfjMc;
	/**
	 * 所属派出所编码
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属派出所编码")
	private Long sspcsBm;
	/**
	 * 所属派出所
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属派出所")
	private String sspcsMc;
	/**
	 * 所属社区编码
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属社区编码")
	private Long sssqBm;
	/**
	 * 所属社区
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属社区")
	private String sssqMc;
	/**
	 * 
	 */
	@ColumnWidth(20)
	@ExcelProperty("")
	private Integer isDeleted;
	/**
	 * 
	 */
	@ColumnWidth(20)
	@ExcelProperty("")
	private String ldph;
	/**
	 * 经度
	 */
	@ColumnWidth(20)
	@ExcelProperty("经度")
	private String jd;
	/**
	 * 纬度
	 */
	@ColumnWidth(20)
	@ExcelProperty("纬度")
	private String wd;
	/**
	 * 警格id
	 */
	@ColumnWidth(20)
	@ExcelProperty("警格id")
	private Long jgId;
	/**
	 * 统一信用代码
	 */
	@ColumnWidth(20)
	@ExcelProperty("统一信用代码")
	private String tyxydm;
	/**
	 * csjc_info表最新id
	 */
	@ColumnWidth(20)
	@ExcelProperty("csjc_info表最新id")
	private Long jcId;
	/**
	 * sspt.rk_ldphxx表xlh
	 */
	@ColumnWidth(20)
	@ExcelProperty("sspt.rk_ldphxx表xlh")
	private Long ldphxlh;
	/**
	 * 0正常 1歇业 2停业
	 */
	@ColumnWidth(20)
	@ExcelProperty("0正常 1歇业 2停业")
	private Integer yyzt;

}
