/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.logMdjfDj.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.log.logMdjfDj.entity.LogMdjfDjEntity;
import org.springblade.modules.log.logMdjfDj.vo.LogMdjfDjVO;
import org.springblade.modules.log.logMdjfDj.excel.LogMdjfDjExcel;
import org.springblade.modules.log.logMdjfDj.wrapper.LogMdjfDjWrapper;
import org.springblade.modules.log.logMdjfDj.service.ILogMdjfDjService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 矛盾纠纷登记表 控制器
 *
 * @author BladeX
 * @since 2024-04-24
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-logMdjfDj/logMdjfDj")
@Api(value = "矛盾纠纷登记表", tags = "矛盾纠纷登记表接口")
public class LogMdjfDjController extends BladeController {

	private final ILogMdjfDjService logMdjfDjService;

	/**
	 * 矛盾纠纷登记表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入logMdjfDj")
	public R<LogMdjfDjVO> detail(LogMdjfDjEntity logMdjfDj) {
		LogMdjfDjEntity detail = logMdjfDjService.getOne(Condition.getQueryWrapper(logMdjfDj));
		return R.data(LogMdjfDjWrapper.build().entityVO(detail));
	}
	/**
	 * 矛盾纠纷登记表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入logMdjfDj")
	public R<IPage<LogMdjfDjVO>> list(@ApiIgnore @RequestParam Map<String, Object> logMdjfDj, Query query) {
		IPage<LogMdjfDjEntity> pages = logMdjfDjService.page(Condition.getPage(query), Condition.getQueryWrapper(logMdjfDj, LogMdjfDjEntity.class));
		return R.data(LogMdjfDjWrapper.build().pageVO(pages));
	}

	/**
	 * 矛盾纠纷登记表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入logMdjfDj")
	public R<IPage<LogMdjfDjVO>> page(LogMdjfDjVO logMdjfDj, Query query) {
		IPage<LogMdjfDjVO> pages = logMdjfDjService.selectLogMdjfDjPage(Condition.getPage(query), logMdjfDj);
		return R.data(pages);
	}

	/**
	 * 矛盾纠纷登记表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入logMdjfDj")
	public R save(@Valid @RequestBody LogMdjfDjEntity logMdjfDj) {
		return R.status(logMdjfDjService.save(logMdjfDj));
	}

	/**
	 * 矛盾纠纷登记表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入logMdjfDj")
	public R update(@Valid @RequestBody LogMdjfDjEntity logMdjfDj) {
		return R.status(logMdjfDjService.updateById(logMdjfDj));
	}

	/**
	 * 矛盾纠纷登记表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入logMdjfDj")
	public R submit(@Valid @RequestBody LogMdjfDjEntity logMdjfDj) {
		return R.status(logMdjfDjService.saveOrUpdate(logMdjfDj));
	}

	/**
	 * 矛盾纠纷登记表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(logMdjfDjService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-logMdjfDj")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入logMdjfDj")
	public void exportLogMdjfDj(@ApiIgnore @RequestParam Map<String, Object> logMdjfDj, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<LogMdjfDjEntity> queryWrapper = Condition.getQueryWrapper(logMdjfDj, LogMdjfDjEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(LogMdjfDj::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(LogMdjfDjEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<LogMdjfDjExcel> list = logMdjfDjService.exportLogMdjfDj(queryWrapper);
		ExcelUtil.export(response, "矛盾纠纷登记表数据" + DateUtil.time(), "矛盾纠纷登记表数据表", list, LogMdjfDjExcel.class);
	}

}
