/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.logUser.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.log.logUser.entity.LogUserEntity;
import org.springblade.modules.log.logUser.vo.LogUserVO;
import org.springblade.modules.log.logUser.excel.LogUserExcel;
import org.springblade.modules.log.logUser.wrapper.LogUserWrapper;
import org.springblade.modules.log.logUser.service.ILogUserService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 社区警务-民警信息 控制器
 *
 * @author BladeX
 * @since 2024-04-09
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-logUser/logUser")
@Api(value = "社区警务-民警信息", tags = "社区警务-民警信息接口")
public class LogUserController extends BladeController {

	private final ILogUserService logUserService;

	/**
	 * 社区警务-民警信息 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入logUser")
	public R<LogUserVO> detail(LogUserEntity logUser) {
		LogUserEntity detail = logUserService.getOne(Condition.getQueryWrapper(logUser));
		return R.data(LogUserWrapper.build().entityVO(detail));
	}
	/**
	 * 社区警务-民警信息 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入logUser")
	public R<IPage<LogUserVO>> list(@ApiIgnore @RequestParam Map<String, Object> logUser, Query query) {
		IPage<LogUserEntity> pages = logUserService.page(Condition.getPage(query), Condition.getQueryWrapper(logUser, LogUserEntity.class));
		return R.data(LogUserWrapper.build().pageVO(pages));
	}

	/**
	 * 社区警务-民警信息 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入logUser")
	public R<IPage<LogUserVO>> page(LogUserVO logUser, Query query) {
		IPage<LogUserVO> pages = logUserService.selectLogUserPage(Condition.getPage(query), logUser);
		return R.data(pages);
	}

	/**
	 * 社区警务-民警信息 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入logUser")
	public R save(@Valid @RequestBody LogUserEntity logUser) {
		return R.status(logUserService.save(logUser));
	}

	/**
	 * 社区警务-民警信息 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入logUser")
	public R update(@Valid @RequestBody LogUserEntity logUser) {
		return R.status(logUserService.updateById(logUser));
	}

	/**
	 * 社区警务-民警信息 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入logUser")
	public R submit(@Valid @RequestBody LogUserEntity logUser) {
		return R.status(logUserService.saveOrUpdate(logUser));
	}

	/**
	 * 社区警务-民警信息 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(logUserService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-logUser")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入logUser")
	public void exportLogUser(@ApiIgnore @RequestParam Map<String, Object> logUser, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<LogUserEntity> queryWrapper = Condition.getQueryWrapper(logUser, LogUserEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(LogUser::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(LogUserEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<LogUserExcel> list = logUserService.exportLogUser(queryWrapper);
		ExcelUtil.export(response, "社区警务-民警信息数据" + DateUtil.time(), "社区警务-民警信息数据表", list, LogUserExcel.class);
	}

}
