/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.logUser.excel;


import lombok.Data;

import java.time.LocalDate;
import java.util.Date;
import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.ColumnWidth;
import com.alibaba.excel.annotation.write.style.ContentRowHeight;
import com.alibaba.excel.annotation.write.style.HeadRowHeight;
import java.io.Serializable;


/**
 * 社区警务-民警信息 Excel实体类
 *
 * @author BladeX
 * @since 2024-04-09
 */
@Data
@ColumnWidth(25)
@HeadRowHeight(20)
@ContentRowHeight(18)
public class LogUserExcel implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * blade_user表id
	 */
	@ColumnWidth(20)
	@ExcelProperty("blade_user表id")
	private Long userId;
	/**
	 * 照片
	 */
	@ColumnWidth(20)
	@ExcelProperty("照片")
	private String zp;
	/**
	 * 姓名
	 */
	@ColumnWidth(20)
	@ExcelProperty("姓名")
	private String xm;
	/**
	 * 性别 1男2女
	 */
	@ColumnWidth(20)
	@ExcelProperty("性别 1男2女")
	private Short xb;
	/**
	 * 身份证号
	 */
	@ColumnWidth(20)
	@ExcelProperty("身份证号")
	private String sfzh;
	/**
	 * 出生日期
	 */
	@ColumnWidth(20)
	@ExcelProperty("出生日期")
	private String csrq;
	/**
	 * 民族
	 */
	@ColumnWidth(20)
	@ExcelProperty("民族")
	private String mz;
	/**
	 * 文化程度
	 */
	@ColumnWidth(20)
	@ExcelProperty("文化程度")
	private String whcd;
	/**
	 * 婚姻状况
	 */
	@ColumnWidth(20)
	@ExcelProperty("婚姻状况")
	private String hyzk;
	/**
	 * 家庭住址
	 */
	@ColumnWidth(20)
	@ExcelProperty("家庭住址")
	private String jtzz;
	/**
	 * 联系电话
	 */
	@ColumnWidth(20)
	@ExcelProperty("联系电话")
	private String lxdh;
	/**
	 * 警号
	 */
	@ColumnWidth(20)
	@ExcelProperty("警号")
	private String jh;
	/**
	 * 政治面貌
	 */
	@ColumnWidth(20)
	@ExcelProperty("政治面貌")
	private String zzmm;
	/**
	 * 工作单位名称
	 */
	@ColumnWidth(20)
	@ExcelProperty("工作单位名称")
	private String gzdwmc;
	/**
	 * 所属责任区
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属责任区")
	private String sszrq;
	/**
	 * 所属警格
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属警格")
	private String ssjg;
	/**
	 * 职务类别
	 */
	@ColumnWidth(20)
	@ExcelProperty("职务类别")
	private String zwlb;
	/**
	 * 岗位职责
	 */
	@ColumnWidth(20)
	@ExcelProperty("岗位职责")
	private String gwzz;
	/**
	 * 是否兼任综合指挥民警 0否1是
	 */
	@ColumnWidth(20)
	@ExcelProperty("是否兼任综合指挥民警 0否1是")
	private Integer zhzhmj;
	/**
	 * 任所长日期
	 */
	@ColumnWidth(20)
	@ExcelProperty("任所长日期")
	private LocalDate rszrq;
	/**
	 * 职级
	 */
	@ColumnWidth(20)
	@ExcelProperty("职级")
	private String zj;
	/**
	 * 进班子职务
	 */
	@ColumnWidth(20)
	@ExcelProperty("进班子职务")
	private String jbzzw;
	/**
	 * 进班子日期
	 */
	@ColumnWidth(20)
	@ExcelProperty("进班子日期")
	private LocalDate jbzrq;
	/**
	 * 包村数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("包村数量")
	private Long bcsl;
	/**
	 * 原单位
	 */
	@ColumnWidth(20)
	@ExcelProperty("原单位")
	private String ydw;
	/**
	 *
	 */
	@ColumnWidth(20)
	@ExcelProperty("")
	private Integer isDeleted;
	/**
	 * 所长附件
	 */
	@ColumnWidth(20)
	@ExcelProperty("所长附件")
	private String szfj;
	/**
	 * 进两委职务
	 */
	@ColumnWidth(20)
	@ExcelProperty("进两委职务")
	private String jlwzw;
	/**
	 * 进两委日期
	 */
	@ColumnWidth(20)
	@ExcelProperty("进两委日期")
	private LocalDate jlwrq;
	/**
	 * 进两委附件
	 */
	@ColumnWidth(20)
	@ExcelProperty("进两委附件")
	private String jlwfj;

}
