/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.rhzfCzrk.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.log.rhzfCzrk.entity.RhzfCzrkEntity;
import org.springblade.modules.log.rhzfCzrk.excel.RhzfCzrkExcel;
import org.springblade.modules.log.rhzfCzrk.service.IRhzfCzrkService;
import org.springblade.modules.log.rhzfCzrk.vo.RhzfCzrkVO;
import org.springblade.modules.log.rhzfCzrk.wrapper.RhzfCzrkWrapper;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 入户走访_人员_常住人口 控制器
 *
 * @author BladeX
 * @since 2024-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-rhzfCzrk/rhzfCzrk")
@Api(value = "入户走访_人员_常住人口", tags = "入户走访_人员_常住人口接口")
public class RhzfCzrkController extends BladeController {

	private final IRhzfCzrkService rhzfCzrkService;

	/**
	 * 入户走访_人员_常住人口 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入rhzfCzrk")
	public R<RhzfCzrkVO> detail(RhzfCzrkEntity rhzfCzrk) {
		RhzfCzrkEntity detail = rhzfCzrkService.getOne(Condition.getQueryWrapper(rhzfCzrk));
		return R.data(RhzfCzrkWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_人员_常住人口 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入rhzfCzrk")
	public R<IPage<RhzfCzrkVO>> list(@ApiIgnore @RequestParam Map<String, Object> rhzfCzrk, Query query) {
		IPage<RhzfCzrkEntity> pages = rhzfCzrkService.page(Condition.getPage(query), Condition.getQueryWrapper(rhzfCzrk, RhzfCzrkEntity.class));
		return R.data(RhzfCzrkWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_人员_常住人口 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入rhzfCzrk")
	public R<IPage<RhzfCzrkVO>> page(RhzfCzrkVO rhzfCzrk, Query query) {
		IPage<RhzfCzrkVO> pages = rhzfCzrkService.selectRhzfCzrkPage(Condition.getPage(query), rhzfCzrk);
		return R.data(pages);
	}

	/**
	 * 入户走访_人员_常住人口 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入rhzfCzrk")
	public R save(@Valid @RequestBody RhzfCzrkEntity rhzfCzrk) {
		return R.status(rhzfCzrkService.save(rhzfCzrk));
	}

	/**
	 * 入户走访_人员_常住人口 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入rhzfCzrk")
	public R update(@Valid @RequestBody RhzfCzrkEntity rhzfCzrk) {
		return R.status(rhzfCzrkService.updateById(rhzfCzrk));
	}

	/**
	 * 入户走访_人员_常住人口 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入rhzfCzrk")
	public R submit(@Valid @RequestBody RhzfCzrkEntity rhzfCzrk) {
		return R.status(rhzfCzrkService.saveOrUpdate(rhzfCzrk));
	}

	/**
	 * 入户走访_人员_常住人口 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(rhzfCzrkService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-rhzfCzrk")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入rhzfCzrk")
	public void exportRhzfCzrk(@ApiIgnore @RequestParam Map<String, Object> rhzfCzrk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RhzfCzrkEntity> queryWrapper = Condition.getQueryWrapper(rhzfCzrk, RhzfCzrkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RhzfCzrk::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RhzfCzrkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RhzfCzrkExcel> list = rhzfCzrkService.exportRhzfCzrk(queryWrapper);
		ExcelUtil.export(response, "入户走访_人员_常住人口数据" + DateUtil.time(), "入户走访_人员_常住人口数据表", list, RhzfCzrkExcel.class);
	}

}
