/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.rhzfFz.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.log.rhzfFz.entity.RhzfFzEntity;
import org.springblade.modules.log.rhzfFz.vo.RhzfFzVO;
import org.springblade.modules.log.rhzfFz.excel.RhzfFzExcel;
import org.springblade.modules.log.rhzfFz.wrapper.RhzfFzWrapper;
import org.springblade.modules.log.rhzfFz.service.IRhzfFzService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_房屋_房主 控制器
 *
 * @author BladeX
 * @since 2024-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-rhzfFz/rhzfFz")
@Api(value = "入户走访_房屋_房主", tags = "入户走访_房屋_房主接口")
public class RhzfFzController extends BladeController {

	private final IRhzfFzService rhzfFzService;

	/**
	 * 入户走访_房屋_房主 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入rhzfFz")
	public R<RhzfFzVO> detail(RhzfFzEntity rhzfFz) {
		RhzfFzEntity detail = rhzfFzService.getOne(Condition.getQueryWrapper(rhzfFz));
		return R.data(RhzfFzWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_房屋_房主 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入rhzfFz")
	public R<IPage<RhzfFzVO>> list(@ApiIgnore @RequestParam Map<String, Object> rhzfFz, Query query) {
		IPage<RhzfFzEntity> pages = rhzfFzService.page(Condition.getPage(query), Condition.getQueryWrapper(rhzfFz, RhzfFzEntity.class));
		return R.data(RhzfFzWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_房屋_房主 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入rhzfFz")
	public R<IPage<RhzfFzVO>> page(RhzfFzVO rhzfFz, Query query) {
		IPage<RhzfFzVO> pages = rhzfFzService.selectRhzfFzPage(Condition.getPage(query), rhzfFz);
		return R.data(pages);
	}

	/**
	 * 入户走访_房屋_房主 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入rhzfFz")
	public R save(@Valid @RequestBody RhzfFzEntity rhzfFz) {
		return R.status(rhzfFzService.save(rhzfFz));
	}

	/**
	 * 入户走访_房屋_房主 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入rhzfFz")
	public R update(@Valid @RequestBody RhzfFzEntity rhzfFz) {
		return R.status(rhzfFzService.updateById(rhzfFz));
	}

	/**
	 * 入户走访_房屋_房主 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入rhzfFz")
	public R submit(@Valid @RequestBody RhzfFzEntity rhzfFz) {
		return R.status(rhzfFzService.saveOrUpdate(rhzfFz));
	}

	/**
	 * 入户走访_房屋_房主 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(rhzfFzService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-rhzfFz")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入rhzfFz")
	public void exportRhzfFz(@ApiIgnore @RequestParam Map<String, Object> rhzfFz, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RhzfFzEntity> queryWrapper = Condition.getQueryWrapper(rhzfFz, RhzfFzEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RhzfFz::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RhzfFzEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RhzfFzExcel> list = rhzfFzService.exportRhzfFz(queryWrapper);
		ExcelUtil.export(response, "入户走访_房屋_房主数据" + DateUtil.time(), "入户走访_房屋_房主数据表", list, RhzfFzExcel.class);
	}

}
