/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.rhzfJwrk.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.log.rhzfJwrk.entity.RhzfJwrkEntity;
import org.springblade.modules.log.rhzfJwrk.vo.RhzfJwrkVO;
import org.springblade.modules.log.rhzfJwrk.excel.RhzfJwrkExcel;
import org.springblade.modules.log.rhzfJwrk.wrapper.RhzfJwrkWrapper;
import org.springblade.modules.log.rhzfJwrk.service.IRhzfJwrkService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_人员_境外人口 控制器
 *
 * @author BladeX
 * @since 2024-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-rhzfJwrk/rhzfJwrk")
@Api(value = "入户走访_人员_境外人口", tags = "入户走访_人员_境外人口接口")
public class RhzfJwrkController extends BladeController {

	private final IRhzfJwrkService rhzfJwrkService;

	/**
	 * 入户走访_人员_境外人口 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入rhzfJwrk")
	public R<RhzfJwrkVO> detail(RhzfJwrkEntity rhzfJwrk) {
		RhzfJwrkEntity detail = rhzfJwrkService.getOne(Condition.getQueryWrapper(rhzfJwrk));
		return R.data(RhzfJwrkWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_人员_境外人口 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入rhzfJwrk")
	public R<IPage<RhzfJwrkVO>> list(@ApiIgnore @RequestParam Map<String, Object> rhzfJwrk, Query query) {
		IPage<RhzfJwrkEntity> pages = rhzfJwrkService.page(Condition.getPage(query), Condition.getQueryWrapper(rhzfJwrk, RhzfJwrkEntity.class));
		return R.data(RhzfJwrkWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_人员_境外人口 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入rhzfJwrk")
	public R<IPage<RhzfJwrkVO>> page(RhzfJwrkVO rhzfJwrk, Query query) {
		IPage<RhzfJwrkVO> pages = rhzfJwrkService.selectRhzfJwrkPage(Condition.getPage(query), rhzfJwrk);
		return R.data(pages);
	}

	/**
	 * 入户走访_人员_境外人口 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入rhzfJwrk")
	public R save(@Valid @RequestBody RhzfJwrkEntity rhzfJwrk) {
		return R.status(rhzfJwrkService.save(rhzfJwrk));
	}

	/**
	 * 入户走访_人员_境外人口 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入rhzfJwrk")
	public R update(@Valid @RequestBody RhzfJwrkEntity rhzfJwrk) {
		return R.status(rhzfJwrkService.updateById(rhzfJwrk));
	}

	/**
	 * 入户走访_人员_境外人口 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入rhzfJwrk")
	public R submit(@Valid @RequestBody RhzfJwrkEntity rhzfJwrk) {
		return R.status(rhzfJwrkService.saveOrUpdate(rhzfJwrk));
	}

	/**
	 * 入户走访_人员_境外人口 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(rhzfJwrkService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-rhzfJwrk")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入rhzfJwrk")
	public void exportRhzfJwrk(@ApiIgnore @RequestParam Map<String, Object> rhzfJwrk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RhzfJwrkEntity> queryWrapper = Condition.getQueryWrapper(rhzfJwrk, RhzfJwrkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RhzfJwrk::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RhzfJwrkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RhzfJwrkExcel> list = rhzfJwrkService.exportRhzfJwrk(queryWrapper);
		ExcelUtil.export(response, "入户走访_人员_境外人口数据" + DateUtil.time(), "入户走访_人员_境外人口数据表", list, RhzfJwrkExcel.class);
	}

}
