/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.rhzfJzrk.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.log.rhzfJzrk.entity.RhzfJzrkEntity;
import org.springblade.modules.log.rhzfJzrk.vo.RhzfJzrkVO;
import org.springblade.modules.log.rhzfJzrk.excel.RhzfJzrkExcel;
import org.springblade.modules.log.rhzfJzrk.wrapper.RhzfJzrkWrapper;
import org.springblade.modules.log.rhzfJzrk.service.IRhzfJzrkService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_人员_寄住人口 控制器
 *
 * @author BladeX
 * @since 2024-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-rhzfJzrk/rhzfJzrk")
@Api(value = "入户走访_人员_寄住人口", tags = "入户走访_人员_寄住人口接口")
public class RhzfJzrkController extends BladeController {

	private final IRhzfJzrkService rhzfJzrkService;

	/**
	 * 入户走访_人员_寄住人口 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入rhzfJzrk")
	public R<RhzfJzrkVO> detail(RhzfJzrkEntity rhzfJzrk) {
		RhzfJzrkEntity detail = rhzfJzrkService.getOne(Condition.getQueryWrapper(rhzfJzrk));
		return R.data(RhzfJzrkWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_人员_寄住人口 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入rhzfJzrk")
	public R<IPage<RhzfJzrkVO>> list(@ApiIgnore @RequestParam Map<String, Object> rhzfJzrk, Query query) {
		IPage<RhzfJzrkEntity> pages = rhzfJzrkService.page(Condition.getPage(query), Condition.getQueryWrapper(rhzfJzrk, RhzfJzrkEntity.class));
		return R.data(RhzfJzrkWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_人员_寄住人口 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入rhzfJzrk")
	public R<IPage<RhzfJzrkVO>> page(RhzfJzrkVO rhzfJzrk, Query query) {
		IPage<RhzfJzrkVO> pages = rhzfJzrkService.selectRhzfJzrkPage(Condition.getPage(query), rhzfJzrk);
		return R.data(pages);
	}

	/**
	 * 入户走访_人员_寄住人口 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入rhzfJzrk")
	public R save(@Valid @RequestBody RhzfJzrkEntity rhzfJzrk) {
		return R.status(rhzfJzrkService.save(rhzfJzrk));
	}

	/**
	 * 入户走访_人员_寄住人口 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入rhzfJzrk")
	public R update(@Valid @RequestBody RhzfJzrkEntity rhzfJzrk) {
		return R.status(rhzfJzrkService.updateById(rhzfJzrk));
	}

	/**
	 * 入户走访_人员_寄住人口 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入rhzfJzrk")
	public R submit(@Valid @RequestBody RhzfJzrkEntity rhzfJzrk) {
		return R.status(rhzfJzrkService.saveOrUpdate(rhzfJzrk));
	}

	/**
	 * 入户走访_人员_寄住人口 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(rhzfJzrkService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-rhzfJzrk")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入rhzfJzrk")
	public void exportRhzfJzrk(@ApiIgnore @RequestParam Map<String, Object> rhzfJzrk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RhzfJzrkEntity> queryWrapper = Condition.getQueryWrapper(rhzfJzrk, RhzfJzrkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RhzfJzrk::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RhzfJzrkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RhzfJzrkExcel> list = rhzfJzrkService.exportRhzfJzrk(queryWrapper);
		ExcelUtil.export(response, "入户走访_人员_寄住人口数据" + DateUtil.time(), "入户走访_人员_寄住人口数据表", list, RhzfJzrkExcel.class);
	}

}
