/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.rhzfWlrk.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.log.rhzfWlrk.entity.RhzfWlrkEntity;
import org.springblade.modules.log.rhzfWlrk.vo.RhzfWlrkVO;
import org.springblade.modules.log.rhzfWlrk.excel.RhzfWlrkExcel;
import org.springblade.modules.log.rhzfWlrk.wrapper.RhzfWlrkWrapper;
import org.springblade.modules.log.rhzfWlrk.service.IRhzfWlrkService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_人员_未落常口 控制器
 *
 * @author BladeX
 * @since 2024-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-rhzfWlrk/rhzfWlrk")
@Api(value = "入户走访_人员_未落常口", tags = "入户走访_人员_未落常口接口")
public class RhzfWlrkController extends BladeController {

	private final IRhzfWlrkService rhzfWlrkService;

	/**
	 * 入户走访_人员_未落常口 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入rhzfWlrk")
	public R<RhzfWlrkVO> detail(RhzfWlrkEntity rhzfWlrk) {
		RhzfWlrkEntity detail = rhzfWlrkService.getOne(Condition.getQueryWrapper(rhzfWlrk));
		return R.data(RhzfWlrkWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_人员_未落常口 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入rhzfWlrk")
	public R<IPage<RhzfWlrkVO>> list(@ApiIgnore @RequestParam Map<String, Object> rhzfWlrk, Query query) {
		IPage<RhzfWlrkEntity> pages = rhzfWlrkService.page(Condition.getPage(query), Condition.getQueryWrapper(rhzfWlrk, RhzfWlrkEntity.class));
		return R.data(RhzfWlrkWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_人员_未落常口 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入rhzfWlrk")
	public R<IPage<RhzfWlrkVO>> page(RhzfWlrkVO rhzfWlrk, Query query) {
		IPage<RhzfWlrkVO> pages = rhzfWlrkService.selectRhzfWlrkPage(Condition.getPage(query), rhzfWlrk);
		return R.data(pages);
	}

	/**
	 * 入户走访_人员_未落常口 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入rhzfWlrk")
	public R save(@Valid @RequestBody RhzfWlrkEntity rhzfWlrk) {
		return R.status(rhzfWlrkService.save(rhzfWlrk));
	}

	/**
	 * 入户走访_人员_未落常口 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入rhzfWlrk")
	public R update(@Valid @RequestBody RhzfWlrkEntity rhzfWlrk) {
		return R.status(rhzfWlrkService.updateById(rhzfWlrk));
	}

	/**
	 * 入户走访_人员_未落常口 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入rhzfWlrk")
	public R submit(@Valid @RequestBody RhzfWlrkEntity rhzfWlrk) {
		return R.status(rhzfWlrkService.saveOrUpdate(rhzfWlrk));
	}

	/**
	 * 入户走访_人员_未落常口 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(rhzfWlrkService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-rhzfWlrk")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入rhzfWlrk")
	public void exportRhzfWlrk(@ApiIgnore @RequestParam Map<String, Object> rhzfWlrk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RhzfWlrkEntity> queryWrapper = Condition.getQueryWrapper(rhzfWlrk, RhzfWlrkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RhzfWlrk::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RhzfWlrkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RhzfWlrkExcel> list = rhzfWlrkService.exportRhzfWlrk(queryWrapper);
		ExcelUtil.export(response, "入户走访_人员_未落常口数据" + DateUtil.time(), "入户走访_人员_未落常口数据表", list, RhzfWlrkExcel.class);
	}

}
