/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.userLogin.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.log.userLogin.entity.UserLoginEntity;
import org.springblade.modules.log.userLogin.vo.UserLoginVO;
import org.springblade.modules.log.userLogin.excel.UserLoginExcel;
import org.springblade.modules.log.userLogin.wrapper.UserLoginWrapper;
import org.springblade.modules.log.userLogin.service.IUserLoginService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 用户登陆日志 控制器
 *
 * @author BladeX
 * @since 2024-04-22
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-userLogin/userLogin")
@Api(value = "用户登陆日志", tags = "用户登陆日志接口")
public class UserLoginController extends BladeController {

	private final IUserLoginService userLoginService;

	/**
	 * 用户登陆日志 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入userLogin")
	public R<UserLoginVO> detail(UserLoginEntity userLogin) {
		UserLoginEntity detail = userLoginService.getOne(Condition.getQueryWrapper(userLogin));
		return R.data(UserLoginWrapper.build().entityVO(detail));
	}
	/**
	 * 用户登陆日志 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入userLogin")
	public R<IPage<UserLoginVO>> list(@ApiIgnore @RequestParam Map<String, Object> userLogin, Query query) {
		IPage<UserLoginEntity> pages = userLoginService.page(Condition.getPage(query), Condition.getQueryWrapper(userLogin, UserLoginEntity.class));
		return R.data(UserLoginWrapper.build().pageVO(pages));
	}

	/**
	 * 用户登陆日志 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入userLogin")
	public R<IPage<UserLoginVO>> page(UserLoginVO userLogin, Query query) {
		IPage<UserLoginVO> pages = userLoginService.selectUserLoginPage(Condition.getPage(query), userLogin);
		return R.data(pages);
	}

	/**
	 * 用户登陆日志 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入userLogin")
	public R save(@Valid @RequestBody UserLoginEntity userLogin) {
		return R.status(userLoginService.save(userLogin));
	}

	/**
	 * 用户登陆日志 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入userLogin")
	public R update(@Valid @RequestBody UserLoginEntity userLogin) {
		return R.status(userLoginService.updateById(userLogin));
	}

	/**
	 * 用户登陆日志 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入userLogin")
	public R submit(@Valid @RequestBody UserLoginEntity userLogin) {
		return R.status(userLoginService.saveOrUpdate(userLogin));
	}

	/**
	 * 用户登陆日志 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(userLoginService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-userLogin")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入userLogin")
	public void exportUserLogin(@ApiIgnore @RequestParam Map<String, Object> userLogin, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<UserLoginEntity> queryWrapper = Condition.getQueryWrapper(userLogin, UserLoginEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(UserLogin::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(UserLoginEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<UserLoginExcel> list = userLoginService.exportUserLogin(queryWrapper);
		ExcelUtil.export(response, "用户登陆日志数据" + DateUtil.time(), "用户登陆日志数据表", list, UserLoginExcel.class);
	}

}
