/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.log.zxLog.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.log.zxLog.entity.ZxLogEntity;
import org.springblade.modules.log.zxLog.excel.ZxLogExcel;
import org.springblade.modules.log.zxLog.service.IZxLogService;
import org.springblade.modules.log.zxLog.vo.ZxLogVO;
import org.springblade.modules.log.zxLog.wrapper.ZxLogWrapper;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 用户注销log 控制器
 *
 * @author BladeX
 * @since 2024-04-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-log/log")
@Api(value = "用户注销log", tags = "用户注销log接口")
public class ZxLogController extends BladeController {

	private final IZxLogService logService;

	/**
	 * 用户注销log 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入log")
	public R<ZxLogVO> detail(ZxLogEntity log) {
		ZxLogEntity detail = logService.getOne(Condition.getQueryWrapper(log));
		return R.data(ZxLogWrapper.build().entityVO(detail));
	}
	/**
	 * 用户注销log 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入log")
	public R<IPage<ZxLogVO>> list(@ApiIgnore @RequestParam Map<String, Object> log, Query query) {
		IPage<ZxLogEntity> pages = logService.page(Condition.getPage(query), Condition.getQueryWrapper(log, ZxLogEntity.class));
		return R.data(ZxLogWrapper.build().pageVO(pages));
	}

	/**
	 * 用户注销log 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入log")
	public R<IPage<ZxLogVO>> page(ZxLogVO log, Query query) {
		IPage<ZxLogVO> pages = logService.selectLogPage(Condition.getPage(query), log);
		return R.data(pages);
	}

	/**
	 * 用户注销log 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入log")
	public R save(@Valid @RequestBody ZxLogEntity log) {
		return R.status(logService.save(log));
	}

	/**
	 * 用户注销log 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入log")
	public R update(@Valid @RequestBody ZxLogEntity log) {
		return R.status(logService.updateById(log));
	}

	/**
	 * 用户注销log 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入log")
	public R submit(@Valid @RequestBody ZxLogEntity log) {
		return R.status(logService.saveOrUpdate(log));
	}

	/**
	 * 用户注销log 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(logService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-log")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入log")
	public void exportLog(@ApiIgnore @RequestParam Map<String, Object> log, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<ZxLogEntity> queryWrapper = Condition.getQueryWrapper(log, ZxLogEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(Log::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(ZxLogEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<ZxLogExcel> list = logService.exportLog(queryWrapper);
		ExcelUtil.export(response, "用户注销log数据" + DateUtil.time(), "用户注销log数据表", list, ZxLogExcel.class);
	}

}
