/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mdjfJq.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.mdjfJq.entity.MdjfJqEntity;
import org.springblade.modules.mdjfJq.excel.MdjfJqExcel;
import org.springblade.modules.mdjfJq.service.IMdjfJqService;
import org.springblade.modules.mdjfJq.vo.MdjfJqVO;
import org.springblade.modules.mdjfJq.wrapper.MdjfJqWrapper;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 矛盾纠纷-警情 关联表 控制器
 *
 * @author BladeX
 * @since 2024-05-24
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-MdjfJq/MdjfJq")
@Api(value = "矛盾纠纷-警情 关联表", tags = "矛盾纠纷-警情 关联表接口")
public class MdjfJqController extends BladeController {

	private final IMdjfJqService mdjfJqService;

	/**
	 * 矛盾纠纷-警情 关联表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入MdjfJq")
	public R<MdjfJqVO> detail(MdjfJqEntity MdjfJq) {
		MdjfJqEntity detail = mdjfJqService.getOne(Condition.getQueryWrapper(MdjfJq));
		return R.data(MdjfJqWrapper.build().entityVO(detail));
	}
	/**
	 * 矛盾纠纷-警情 关联表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入MdjfJq")
	public R<IPage<MdjfJqVO>> list(@ApiIgnore @RequestParam Map<String, Object> MdjfJq, Query query) {
		IPage<MdjfJqEntity> pages = mdjfJqService.page(Condition.getPage(query), Condition.getQueryWrapper(MdjfJq, MdjfJqEntity.class));
		return R.data(MdjfJqWrapper.build().pageVO(pages));
	}

	/**
	 * 矛盾纠纷-警情 关联表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入MdjfJq")
	public R<IPage<MdjfJqVO>> page(MdjfJqVO MdjfJq, Query query) {
		IPage<MdjfJqVO> pages = mdjfJqService.selectmdjfJqPage(Condition.getPage(query), MdjfJq);
		return R.data(pages);
	}

	/**
	 * 矛盾纠纷-警情 关联表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入MdjfJq")
	public R save(@Valid @RequestBody MdjfJqEntity mdjfJqEntity) {
		if (null == mdjfJqEntity || StringUtils.isBlank(mdjfJqEntity.getJjdbh()) || null == mdjfJqEntity.getId()) {
			return R.fail("关联失败，清尝试清理浏览器缓存，并重新登陆");
		}
		return R.status(mdjfJqService.save(mdjfJqEntity));
	}

	/**
	 * 矛盾纠纷-警情 关联表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入MdjfJq")
	public R update(@Valid @RequestBody MdjfJqEntity MdjfJq) {
		return R.status(mdjfJqService.updateById(MdjfJq));
	}

	/**
	 * 矛盾纠纷-警情 关联表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入MdjfJq")
	public R submit(@Valid @RequestBody MdjfJqEntity MdjfJq) {
		return R.status(mdjfJqService.saveOrUpdate(MdjfJq));
	}

	/**
	 * 矛盾纠纷-警情 关联表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(mdjfJqService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-MdjfJq")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入MdjfJq")
	public void exportmdjfJq(@ApiIgnore @RequestParam Map<String, Object> MdjfJq, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<MdjfJqEntity> queryWrapper = Condition.getQueryWrapper(MdjfJq, MdjfJqEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(mdjfJq::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(MdjfJqEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<MdjfJqExcel> list = mdjfJqService.exportmdjfJq(queryWrapper);
		ExcelUtil.export(response, "矛盾纠纷-警情 关联表数据" + DateUtil.time(), "矛盾纠纷-警情 关联表数据表", list, MdjfJqExcel.class);
	}

}
