/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mdjfry.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.mdjfry.entity.MdjfRyEntity;
import org.springblade.modules.mdjfry.excel.MdjfRyExcel;
import org.springblade.modules.mdjfry.service.IMdjfRyService;
import org.springblade.modules.mdjfry.vo.MdjfRyVO;
import org.springblade.modules.mdjfry.wrapper.MdjfRyWrapper;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 纠纷人员登记表 控制器
 *
 * @author BladeX
 * @since 2023-08-02
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-mdjfry/mdjfry")
@Api(value = "纠纷人员登记表", tags = "纠纷人员登记表接口")
public class MdjfRyController extends BladeController {

	private final IMdjfRyService mdjfryService;

	/**
	 * 纠纷人员登记表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入mdjfry")
	public R<MdjfRyVO> detail(MdjfRyEntity mdjfry) {
		MdjfRyEntity detail = mdjfryService.getOne(Condition.getQueryWrapper(mdjfry));
		return R.data(MdjfRyWrapper.build().entityVO(detail));
	}
	/**
	 * 纠纷人员登记表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入mdjfry")
	public R<IPage<MdjfRyVO>> list(@ApiIgnore @RequestParam Map<String, Object> mdjfry, Query query) {
		IPage<MdjfRyEntity> pages = mdjfryService.page(Condition.getPage(query), Condition.getQueryWrapper(mdjfry, MdjfRyEntity.class));
		return R.data(MdjfRyWrapper.build().pageVO(pages));
	}

	/**
	 * 纠纷人员登记表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入mdjfry")
	public R<IPage<MdjfRyEntity>> page(MdjfRyEntity mdjfry, Query query) {
		IPage<MdjfRyEntity> pages = mdjfryService.selectmdjfRyPage(Condition.getPage(query), mdjfry);
		return R.data(pages);
	}

	/**
	 * 纠纷人员登记表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入mdjfry")
	public R save(@Valid @RequestBody MdjfRyEntity mdjfry) {
		return R.status(mdjfryService.save(mdjfry));
	}

	/**
	 * 纠纷人员登记表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入mdjfry")
	public R update(@Valid @RequestBody MdjfRyEntity mdjfry) {
		return R.status(mdjfryService.updateById(mdjfry));
	}

	/**
	 * 纠纷人员登记表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入mdjfry")
	public R submit(@Valid @RequestBody MdjfRyEntity mdjfry) {
		return R.status(mdjfryService.saveOrUpdate(mdjfry));
	}

	/**
	 * 纠纷人员登记表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(mdjfryService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-mdjfry")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入mdjfry")
	public void exportmdjfRy(@ApiIgnore @RequestParam Map<String, Object> mdjfry, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<MdjfRyEntity> queryWrapper = Condition.getQueryWrapper(mdjfry, MdjfRyEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(mdjfRy::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(MdjfRyEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<MdjfRyExcel> list = mdjfryService.exportmdjfRy(queryWrapper);
		ExcelUtil.export(response, "纠纷人员登记表数据" + DateUtil.time(), "纠纷人员登记表数据表", list, MdjfRyExcel.class);
	}

}
