/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mdjfxj.djXj.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springblade.common.cache.DictBizCache;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.mdjfdj.entity.MdjfDjEntity;
import org.springblade.modules.mdjfdj.vo.MdjfDjVO;
import org.springblade.modules.mdjfry.entity.MdjfRyEntity;
import org.springblade.modules.mdjftj.entity.MdjfTjEntity;
import org.springblade.modules.mdjfxj.djXj.entity.DjXjEntity;
import org.springblade.modules.mdjfxj.djXj.excel.DjXjExcel;
import org.springblade.modules.mdjfxj.djXj.service.IDjXjService;
import org.springblade.modules.mdjfxj.djXj.vo.DjXjVO;
import org.springblade.modules.mdjfxj.djXj.wrapper.DjXjWrapper;
import org.springblade.modules.mdjfxj.hfXj.service.IHfXjService;
import org.springblade.modules.mdjfxj.ryXj.entity.RyXjEntity;
import org.springblade.modules.mdjfxj.ryXj.service.IRyXjService;
import org.springblade.modules.mdjfxj.tjXj.entity.TjXjEntity;
import org.springblade.modules.mdjfxj.tjXj.service.ITjXjService;
import org.springblade.modules.system.entity.Dept;
import org.springblade.modules.system.service.IDeptService;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 矛盾纠纷巡警登记表 控制器
 *
 * @author BladeX
 * @since 2024-04-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-djXj/djXj")
@Api(value = "矛盾纠纷巡警登记表", tags = "矛盾纠纷巡警登记表接口")
public class DjXjController extends BladeController {

	private final IDjXjService djXjService;

	private final IHfXjService hfXjService;

	private final IRyXjService ryXjService;

	private final ITjXjService tjXjService;

	private final IDeptService deptService;

	/**
	 * 矛盾纠纷巡警登记表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入djXj")
	public R<DjXjVO> detail(DjXjEntity djXj) {
		DjXjEntity detail = djXjService.getOne(Condition.getQueryWrapper(djXj));
		return R.data(DjXjWrapper.build().entityVO(detail));
	}
	/**
	 * 矛盾纠纷巡警登记表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入djXj")
	public R<IPage<DjXjVO>> list(@ApiIgnore @RequestParam Map<String, Object> djXj, Query query) {
		IPage<DjXjEntity> pages = djXjService.page(Condition.getPage(query), Condition.getQueryWrapper(djXj, DjXjEntity.class));
		return R.data(DjXjWrapper.build().pageVO(pages));
	}

	/**
	 * 矛盾纠纷巡警登记表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入djXj")
	public R<IPage<DjXjVO>> page(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		IPage<DjXjVO> pages = djXjService.selectDjXjPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 矛盾纠纷巡警登记表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入djXj")
	public R save(@Valid @RequestBody DjXjEntity djXj) {
		return R.status(djXjService.save(djXj));
	}

	/**
	 * 矛盾纠纷巡警登记表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入djXj")
	public R update(@Valid @RequestBody DjXjEntity djXj) {
		if (null == djXj.getId()) {
			return R.fail("请重试");
		}
		return R.status(djXjService.updateById(djXj));
	}

	/**
	 * 矛盾纠纷巡警登记表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入djXj")
	public R submit(@Valid @RequestBody DjXjEntity djXj) {
		return R.status(djXjService.saveOrUpdate(djXj));
	}

	/**
	 * 矛盾纠纷巡警登记表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(djXjService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-djXj")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入djXj")
	public void exportDjXj(@ApiIgnore @RequestParam Map<String, Object> djXj, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<DjXjEntity> queryWrapper = Condition.getQueryWrapper(djXj, DjXjEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(DjXj::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(DjXjEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<DjXjExcel> list = djXjService.exportDjXj(queryWrapper);
		ExcelUtil.export(response, "矛盾纠纷巡警登记表数据" + DateUtil.time(), "矛盾纠纷巡警登记表数据表", list, DjXjExcel.class);
	}

	/**
	 * 矛盾纠纷登记
	 */
	@PostMapping("/mdjfDj")
	public R mdjfDj(@RequestBody DjXjVO mdjfdj) {
		DjXjEntity mdjf = mdjfdj.getMdjfDj();
		//添加矛盾已回访次数 默认0   回访状态 默认0   回访是否超时 0
		mdjf.setYhfcs(0);
		mdjf.setCscs(0);
		if (StringUtils.isNotBlank(mdjf.getMdjbV())) {
			String mdjbV = mdjf.getMdjbV();
			mdjf.setXhfcs(Integer.valueOf(DictBizCache.getValue("mdhfcs", mdjbV)));
		}

		// 矛盾纠纷登记
		djXjService.save(mdjf);
		// 人员登记
		if (null != mdjfdj.getMdjfRyList() && mdjfdj.getMdjfRyList().size() > 0) {
			List<RyXjEntity> mdjfRyList = mdjfdj.getMdjfRyList();
			for (int i = 0; i < mdjfRyList.size(); i++) {
				mdjfRyList.get(i).setJfId(mdjf.getId());
			}
			ryXjService.saveBatch(mdjfRyList);
		}
		// 调解记录
		if (null != mdjfdj.getMdjfTjList() && mdjfdj.getMdjfTjList().size() > 0) {
			List<TjXjEntity> mdjfTjList = mdjfdj.getMdjfTjList();
			for (int i = 0; i < mdjfTjList.size(); i++) {
				mdjfTjList.get(i).setJfId(mdjf.getId());
			}
			tjXjService.saveBatch(mdjfTjList);
		}
		return R.data(mdjf.getId());
	}

	/**
	 * 矛盾纠纷登记表 自定义分页
	 */
	@GetMapping("/page-app")
	public R pageToApp(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		params.put("userId", AuthUtil.getUserId());
		String[] mdIds = new String[0];
		if (params.get("mdId") != null) {
			String mdId = params.get("mdId").toString();
			mdIds = mdId.split(",");
		}
		IPage<DjXjVO> pages = djXjService.pageToApp(Condition.getPage(query), params, mdIds);
		return R.data(pages);
	}

	/**
	 * 矛盾纠纷详情
	 */
	@GetMapping("/detailById")
	public R detailById(@RequestParam Long id) {
		DjXjEntity mdjfDj = djXjService.getById(id);
		List<RyXjEntity> mdjfRyList = ryXjService.getRyByMdId(id);
		DjXjVO mdjfDetail = new DjXjVO(mdjfDj, mdjfRyList, new ArrayList<TjXjEntity>());
		return R.data(mdjfDetail);
	}

	/**
	 * 获取当前用户的部门
	 */
	@GetMapping("getUserDept")
	public R getUserDept() {
		List<Dept> list = new ArrayList<>();
		String[] split = AuthUtil.getDeptId().split(",");
		for (String dept:split) {
			Dept byId = deptService.getById(Long.valueOf(dept));
			list.add(byId);
		}
		return R.data(list);
	}

	/**
	 * 派出所登陆查看未移交列表
	 */
	@GetMapping("getMdByPcs")
	public R getMdByPcs(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		return R.data(djXjService.getMdByPcs(Condition.getPage(query), params));
	}

	/**
	 * 派出所登陆查看已移交列表
	 */
	@GetMapping("getMdyjByPcs")
	public R getMdyjByPcs(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		return R.data(djXjService.getMdyjByPcs(Condition.getPage(query), params));
	}
}
