/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mdjfxj.pjXj.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.mdjfxj.pjXj.entity.PjXjEntity;
import org.springblade.modules.mdjfxj.pjXj.vo.PjXjVO;
import org.springblade.modules.mdjfxj.pjXj.excel.PjXjExcel;
import org.springblade.modules.mdjfxj.pjXj.wrapper.PjXjWrapper;
import org.springblade.modules.mdjfxj.pjXj.service.IPjXjService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 矛盾纠纷评价 控制器
 *
 * @author BladeX
 * @since 2024-04-19
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-pjXj/pjXj")
@Api(value = "矛盾纠纷评价", tags = "矛盾纠纷评价接口")
public class PjXjController extends BladeController {

	private final IPjXjService pjXjService;

	/**
	 * 矛盾纠纷评价 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入pjXj")
	public R<PjXjVO> detail(PjXjEntity pjXj) {
		PjXjEntity detail = pjXjService.getOne(Condition.getQueryWrapper(pjXj));
		return R.data(PjXjWrapper.build().entityVO(detail));
	}
	/**
	 * 矛盾纠纷评价 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入pjXj")
	public R<IPage<PjXjVO>> list(@ApiIgnore @RequestParam Map<String, Object> pjXj, Query query) {
		IPage<PjXjEntity> pages = pjXjService.page(Condition.getPage(query), Condition.getQueryWrapper(pjXj, PjXjEntity.class));
		return R.data(PjXjWrapper.build().pageVO(pages));
	}

	/**
	 * 矛盾纠纷评价 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入pjXj")
	public R<IPage<PjXjVO>> page(PjXjVO pjXj, Query query) {
		IPage<PjXjVO> pages = pjXjService.selectPjXjPage(Condition.getPage(query), pjXj);
		return R.data(pages);
	}

	/**
	 * 矛盾纠纷评价 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入pjXj")
	public R save(@Valid @RequestBody PjXjEntity pjXj) {
		return R.status(pjXjService.save(pjXj));
	}

	/**
	 * 矛盾纠纷评价 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入pjXj")
	public R update(@Valid @RequestBody PjXjEntity pjXj) {
		return R.status(pjXjService.updateById(pjXj));
	}

	/**
	 * 矛盾纠纷评价 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入pjXj")
	public R submit(@Valid @RequestBody PjXjEntity pjXj) {
		return R.status(pjXjService.saveOrUpdate(pjXj));
	}

	/**
	 * 矛盾纠纷评价 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(pjXjService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-pjXj")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入pjXj")
	public void exportPjXj(@ApiIgnore @RequestParam Map<String, Object> pjXj, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<PjXjEntity> queryWrapper = Condition.getQueryWrapper(pjXj, PjXjEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(PjXj::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(PjXjEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<PjXjExcel> list = pjXjService.exportPjXj(queryWrapper);
		ExcelUtil.export(response, "矛盾纠纷评价数据" + DateUtil.time(), "矛盾纠纷评价数据表", list, PjXjExcel.class);
	}

}
