/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.mdjfxj.ryXj.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.mdjfxj.ryXj.entity.RyXjEntity;
import org.springblade.modules.mdjfxj.ryXj.vo.RyXjVO;
import org.springblade.modules.mdjfxj.ryXj.excel.RyXjExcel;
import org.springblade.modules.mdjfxj.ryXj.wrapper.RyXjWrapper;
import org.springblade.modules.mdjfxj.ryXj.service.IRyXjService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 纠纷人员登记表 控制器
 *
 * @author BladeX
 * @since 2024-04-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-ryXj/ryXj")
@Api(value = "纠纷人员登记表", tags = "纠纷人员登记表接口")
public class RyXjController extends BladeController {

	private final IRyXjService ryXjService;

	/**
	 * 纠纷人员登记表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入ryXj")
	public R<RyXjVO> detail(RyXjEntity ryXj) {
		RyXjEntity detail = ryXjService.getOne(Condition.getQueryWrapper(ryXj));
		return R.data(RyXjWrapper.build().entityVO(detail));
	}
	/**
	 * 纠纷人员登记表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入ryXj")
	public R<IPage<RyXjVO>> list(@ApiIgnore @RequestParam Map<String, Object> ryXj, Query query) {
		IPage<RyXjEntity> pages = ryXjService.page(Condition.getPage(query), Condition.getQueryWrapper(ryXj, RyXjEntity.class));
		return R.data(RyXjWrapper.build().pageVO(pages));
	}

	/**
	 * 纠纷人员登记表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入ryXj")
	public R<IPage<RyXjVO>> page(RyXjVO ryXj, Query query) {
		IPage<RyXjVO> pages = ryXjService.selectRyXjPage(Condition.getPage(query), ryXj);
		return R.data(pages);
	}

	/**
	 * 纠纷人员登记表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入ryXj")
	public R save(@Valid @RequestBody RyXjEntity ryXj) {
		return R.status(ryXjService.save(ryXj));
	}

	/**
	 * 纠纷人员登记表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入ryXj")
	public R update(@Valid @RequestBody RyXjEntity ryXj) {
		return R.status(ryXjService.updateById(ryXj));
	}

	/**
	 * 纠纷人员登记表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入ryXj")
	public R submit(@Valid @RequestBody RyXjEntity ryXj) {
		return R.status(ryXjService.saveOrUpdate(ryXj));
	}

	/**
	 * 纠纷人员登记表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(ryXjService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-ryXj")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入ryXj")
	public void exportRyXj(@ApiIgnore @RequestParam Map<String, Object> ryXj, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RyXjEntity> queryWrapper = Condition.getQueryWrapper(ryXj, RyXjEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RyXj::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RyXjEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RyXjExcel> list = ryXjService.exportRyXj(queryWrapper);
		ExcelUtil.export(response, "纠纷人员登记表数据" + DateUtil.time(), "纠纷人员登记表数据表", list, RyXjExcel.class);
	}

}
