/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.pfb.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.pfb.entity.PfbData;
import org.springblade.modules.pfb.entity.PfbXlEntity;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.pfb.entity.PfbEntity;
import org.springblade.modules.pfb.vo.PfbVO;
import org.springblade.modules.pfb.excel.PfbExcel;
import org.springblade.modules.pfb.wrapper.PfbWrapper;
import org.springblade.modules.pfb.service.IPfbService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;

import java.util.ArrayList;
import java.util.Date;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 警员评分表 控制器
 *
 * @author BladeX
 * @since 2023-07-11
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-pfb/pfb")
@Api(value = "警员评分表", tags = "警员评分表接口")
public class PfbController extends BladeController {

	private final IPfbService pfbService;

	/**
	 * 警员评分表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入pfb")
	public R<PfbVO> detail(PfbEntity pfb) {
		PfbEntity detail = pfbService.getOne(Condition.getQueryWrapper(pfb));
		return R.data(PfbWrapper.build().entityVO(detail));
	}
	/**
	 * 警员评分表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入pfb")
	public R<IPage<PfbVO>> list(@ApiIgnore @RequestParam Map<String, Object> pfb, Query query) {
		IPage<PfbEntity> pages = pfbService.page(Condition.getPage(query), Condition.getQueryWrapper(pfb, PfbEntity.class));
		return R.data(PfbWrapper.build().pageVO(pages));
	}

	/**
	 * 警员评分表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入pfb")
	public R<IPage<PfbVO>> page(PfbVO pfb, Query query) {
		IPage<PfbVO> pages = pfbService.selectPfbPage(Condition.getPage(query), pfb);
		return R.data(pages);
	}

	/**
	 * 警员评分表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入pfb")
	public R save(@Valid @RequestBody PfbEntity pfb) {
		return R.status(pfbService.save(pfb));
	}

	/**
	 * 警员评分表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入pfb")
	public R update(@Valid @RequestBody PfbEntity pfb) {
		return R.status(pfbService.updateById(pfb));
	}

	/**
	 * 警员评分表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入pfb")
	public R submit(@Valid @RequestBody PfbEntity pfb) {
		return R.status(pfbService.saveOrUpdate(pfb));
	}

	/**
	 * 警员评分表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(pfbService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-pfb")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入pfb")
	public void exportPfb(@ApiIgnore @RequestParam Map<String, Object> pfb, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<PfbEntity> queryWrapper = Condition.getQueryWrapper(pfb, PfbEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(Pfb::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(PfbEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<PfbExcel> list = pfbService.exportPfb(queryWrapper);
		ExcelUtil.export(response, "警员评分表数据" + DateUtil.time(), "警员评分表数据表", list, PfbExcel.class);
	}


	/**
	 * 评分
	 * @param pfbXlEntity
	 * @return
	 */
	@PostMapping("/addPf")
	public R addPf(@RequestBody PfbXlEntity pfbXlEntity){
		String ryid = pfbXlEntity.getRyid();
		List<PfbData> pfbData = pfbXlEntity.getPfbData();
		List<PfbEntity> pfbEntities = new ArrayList<>();
		Date parse = DateUtil.parse(pfbXlEntity.getKhyf()+" 00:00:00", "yyyy-MM-dd HH:mm:ss");
		for (PfbData p:pfbData
			 ) {
			QueryWrapper<PfbEntity> qe = new QueryWrapper<>();
			qe.eq("pfxid",Long.parseLong(p.getXlid()));
			qe.eq("ryid",Long.parseLong(ryid));
			qe.eq("pfyf",parse);
			PfbEntity one = pfbService.getOne(qe);
			PfbEntity pfbEntity = new PfbEntity();
			if(one !=null){
				pfbEntity = one;
			}
			pfbEntity.setPfxid(Long.parseLong(p.getXlid()));
			pfbEntity.setDwpf(p.getDwdf());
			pfbEntity.setRyid(Long.parseLong(ryid));
			pfbEntity.setPfxmc(p.getXl());
			pfbEntity.setPfyf(parse);
//			pfbEntities.add(pfbEntity);
			pfbService.saveOrUpdate(pfbEntity);
		}
//		pfbService.saveBatch(pfbEntities);
		return R.data("操作成功");
	}

}
