/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.rhzf.jxcs.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.rhzf.jxcs.entity.JxcsEntity;
import org.springblade.modules.rhzf.jxcs.vo.JxcsVO;
import org.springblade.modules.rhzf.jxcs.excel.JxcsExcel;
import org.springblade.modules.rhzf.jxcs.wrapper.JxcsWrapper;
import org.springblade.modules.rhzf.jxcs.service.IJxcsService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_九小场所 控制器
 *
 * @author BladeX
 * @since 2023-12-17
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-jxcs/jxcs")
@Api(value = "入户走访_九小场所", tags = "入户走访_九小场所接口")
public class JxcsController extends BladeController {

	private final IJxcsService jxcsService;

	/**
	 * 入户走访_九小场所 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入jxcs")
	public R<JxcsVO> detail(JxcsEntity jxcs) {
		JxcsEntity detail = jxcsService.getOne(Condition.getQueryWrapper(jxcs));
		return R.data(JxcsWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_九小场所 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入jxcs")
	public R<IPage<JxcsVO>> list(@ApiIgnore @RequestParam Map<String, Object> jxcs, Query query) {
		IPage<JxcsEntity> pages = jxcsService.page(Condition.getPage(query), Condition.getQueryWrapper(jxcs, JxcsEntity.class));
		return R.data(JxcsWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_九小场所 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入jxcs")
	public R<IPage<JxcsVO>> page(JxcsVO jxcs, Query query) {
		IPage<JxcsVO> pages = jxcsService.selectJxcsPage(Condition.getPage(query), jxcs);
		return R.data(pages);
	}

	/**
	 * 入户走访_九小场所 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入jxcs")
	public R save(@Valid @RequestBody JxcsEntity jxcs) {
		return R.status(jxcsService.save(jxcs));
	}

	/**
	 * 入户走访_九小场所 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入jxcs")
	public R update(@Valid @RequestBody JxcsEntity jxcs) {
		return R.status(jxcsService.updateById(jxcs));
	}

	/**
	 * 入户走访_九小场所 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入jxcs")
	public R submit(@Valid @RequestBody JxcsEntity jxcs) {
		return R.status(jxcsService.saveOrUpdate(jxcs));
	}

	/**
	 * 入户走访_九小场所 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(jxcsService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-jxcs")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入jxcs")
	public void exportJxcs(@ApiIgnore @RequestParam Map<String, Object> jxcs, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JxcsEntity> queryWrapper = Condition.getQueryWrapper(jxcs, JxcsEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(Jxcs::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(JxcsEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JxcsExcel> list = jxcsService.exportJxcs(queryWrapper);
		ExcelUtil.export(response, "入户走访_九小场所数据" + DateUtil.time(), "入户走访_九小场所数据表", list, JxcsExcel.class);
	}

}
