/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.rhzf.ryCzrk.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.rhzf.ryCzrk.entity.RyCzrkEntity;
import org.springblade.modules.rhzf.ryCzrk.vo.RyCzrkVO;
import org.springblade.modules.rhzf.ryCzrk.excel.RyCzrkExcel;
import org.springblade.modules.rhzf.ryCzrk.wrapper.RyCzrkWrapper;
import org.springblade.modules.rhzf.ryCzrk.service.IRyCzrkService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_人员_常住人口 控制器
 *
 * @author BladeX
 * @since 2023-11-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-ryCzrk/ryCzrk")
@Api(value = "入户走访_人员_常住人口", tags = "入户走访_人员_常住人口接口")
public class RyCzrkController extends BladeController {

	private final IRyCzrkService ryCzrkService;

	/**
	 * 入户走访_人员_常住人口 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入ryCzrk")
	public R<RyCzrkVO> detail(RyCzrkEntity ryCzrk) {
		RyCzrkEntity detail = ryCzrkService.getOne(Condition.getQueryWrapper(ryCzrk));
		return R.data(RyCzrkWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_人员_常住人口 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入ryCzrk")
	public R<IPage<RyCzrkVO>> list(@ApiIgnore @RequestParam Map<String, Object> ryCzrk, Query query) {
		IPage<RyCzrkEntity> pages = ryCzrkService.page(Condition.getPage(query), Condition.getQueryWrapper(ryCzrk, RyCzrkEntity.class));
		return R.data(RyCzrkWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_人员_常住人口 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入ryCzrk")
	public R<IPage<RyCzrkVO>> page(RyCzrkVO ryCzrk, Query query) {
		IPage<RyCzrkVO> pages = ryCzrkService.selectRyCzrkPage(Condition.getPage(query), ryCzrk);
		return R.data(pages);
	}

	/**
	 * 入户走访_人员_常住人口 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入ryCzrk")
	public R save(@Valid @RequestBody RyCzrkEntity ryCzrk) {
		return R.status(ryCzrkService.save(ryCzrk));
	}

	/**
	 * 入户走访_人员_常住人口 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入ryCzrk")
	public R update(@Valid @RequestBody RyCzrkEntity ryCzrk) {
		return R.status(ryCzrkService.updateById(ryCzrk));
	}

	/**
	 * 入户走访_人员_常住人口 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入ryCzrk")
	public R submit(@Valid @RequestBody RyCzrkEntity ryCzrk) {
		return R.status(ryCzrkService.saveOrUpdate(ryCzrk));
	}

	/**
	 * 入户走访_人员_常住人口 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(ryCzrkService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-ryCzrk")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入ryCzrk")
	public void exportRyCzrk(@ApiIgnore @RequestParam Map<String, Object> ryCzrk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RyCzrkEntity> queryWrapper = Condition.getQueryWrapper(ryCzrk, RyCzrkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RyCzrk::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RyCzrkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RyCzrkExcel> list = ryCzrkService.exportRyCzrk(queryWrapper);
		ExcelUtil.export(response, "入户走访_人员_常住人口数据" + DateUtil.time(), "入户走访_人员_常住人口数据表", list, RyCzrkExcel.class);
	}

}
