/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.rhzf.ryJzrk.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.rhzf.ryJzrk.entity.RyJzrkEntity;
import org.springblade.modules.rhzf.ryJzrk.vo.RyJzrkVO;
import org.springblade.modules.rhzf.ryJzrk.excel.RyJzrkExcel;
import org.springblade.modules.rhzf.ryJzrk.wrapper.RyJzrkWrapper;
import org.springblade.modules.rhzf.ryJzrk.service.IRyJzrkService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_人员_寄住人口 控制器
 *
 * @author BladeX
 * @since 2023-11-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-ryJzrk/ryJzrk")
@Api(value = "入户走访_人员_寄住人口", tags = "入户走访_人员_寄住人口接口")
public class RyJzrkController extends BladeController {

	private final IRyJzrkService ryJzrkService;

	/**
	 * 入户走访_人员_寄住人口 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入ryJzrk")
	public R<RyJzrkVO> detail(RyJzrkEntity ryJzrk) {
		RyJzrkEntity detail = ryJzrkService.getOne(Condition.getQueryWrapper(ryJzrk));
		return R.data(RyJzrkWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_人员_寄住人口 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入ryJzrk")
	public R<IPage<RyJzrkVO>> list(@ApiIgnore @RequestParam Map<String, Object> ryJzrk, Query query) {
		IPage<RyJzrkEntity> pages = ryJzrkService.page(Condition.getPage(query), Condition.getQueryWrapper(ryJzrk, RyJzrkEntity.class));
		return R.data(RyJzrkWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_人员_寄住人口 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入ryJzrk")
	public R<IPage<RyJzrkVO>> page(RyJzrkVO ryJzrk, Query query) {
		IPage<RyJzrkVO> pages = ryJzrkService.selectRyJzrkPage(Condition.getPage(query), ryJzrk);
		return R.data(pages);
	}

	/**
	 * 入户走访_人员_寄住人口 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入ryJzrk")
	public R save(@Valid @RequestBody RyJzrkEntity ryJzrk) {
		return R.status(ryJzrkService.save(ryJzrk));
	}

	/**
	 * 入户走访_人员_寄住人口 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入ryJzrk")
	public R update(@Valid @RequestBody RyJzrkEntity ryJzrk) {
		return R.status(ryJzrkService.updateById(ryJzrk));
	}

	/**
	 * 入户走访_人员_寄住人口 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入ryJzrk")
	public R submit(@Valid @RequestBody RyJzrkEntity ryJzrk) {
		return R.status(ryJzrkService.saveOrUpdate(ryJzrk));
	}

	/**
	 * 入户走访_人员_寄住人口 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(ryJzrkService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-ryJzrk")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入ryJzrk")
	public void exportRyJzrk(@ApiIgnore @RequestParam Map<String, Object> ryJzrk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RyJzrkEntity> queryWrapper = Condition.getQueryWrapper(ryJzrk, RyJzrkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RyJzrk::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RyJzrkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RyJzrkExcel> list = ryJzrkService.exportRyJzrk(queryWrapper);
		ExcelUtil.export(response, "入户走访_人员_寄住人口数据" + DateUtil.time(), "入户走访_人员_寄住人口数据表", list, RyJzrkExcel.class);
	}

}
