/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.rhzf.ryZzrk.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.rhzf.ryZzrk.entity.RyZzrkEntity;
import org.springblade.modules.rhzf.ryZzrk.vo.RyZzrkVO;
import org.springblade.modules.rhzf.ryZzrk.excel.RyZzrkExcel;
import org.springblade.modules.rhzf.ryZzrk.wrapper.RyZzrkWrapper;
import org.springblade.modules.rhzf.ryZzrk.service.IRyZzrkService;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * 入户走访_人员_暂住人口 控制器
 *
 * @author BladeX
 * @since 2023-11-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-ryZzrk/ryZzrk")
@Api(value = "入户走访_人员_暂住人口", tags = "入户走访_人员_暂住人口接口")
public class RyZzrkController extends BladeController {

	private final IRyZzrkService ryZzrkService;

	/**
	 * 入户走访_人员_暂住人口 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入ryZzrk")
	public R<RyZzrkVO> detail(RyZzrkEntity ryZzrk) {
		RyZzrkEntity detail = ryZzrkService.getOne(Condition.getQueryWrapper(ryZzrk));
		return R.data(RyZzrkWrapper.build().entityVO(detail));
	}
	/**
	 * 入户走访_人员_暂住人口 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入ryZzrk")
	public R<IPage<RyZzrkVO>> list(@ApiIgnore @RequestParam Map<String, Object> ryZzrk, Query query) {
		IPage<RyZzrkEntity> pages = ryZzrkService.page(Condition.getPage(query), Condition.getQueryWrapper(ryZzrk, RyZzrkEntity.class));
		return R.data(RyZzrkWrapper.build().pageVO(pages));
	}

	/**
	 * 入户走访_人员_暂住人口 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入ryZzrk")
	public R<IPage<RyZzrkVO>> page(RyZzrkVO ryZzrk, Query query) {
		IPage<RyZzrkVO> pages = ryZzrkService.selectRyZzrkPage(Condition.getPage(query), ryZzrk);
		return R.data(pages);
	}

	/**
	 * 入户走访_人员_暂住人口 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入ryZzrk")
	public R save(@Valid @RequestBody RyZzrkEntity ryZzrk) {
		return R.status(ryZzrkService.save(ryZzrk));
	}

	/**
	 * 入户走访_人员_暂住人口 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入ryZzrk")
	public R update(@Valid @RequestBody RyZzrkEntity ryZzrk) {
		return R.status(ryZzrkService.updateById(ryZzrk));
	}

	/**
	 * 入户走访_人员_暂住人口 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入ryZzrk")
	public R submit(@Valid @RequestBody RyZzrkEntity ryZzrk) {
		return R.status(ryZzrkService.saveOrUpdate(ryZzrk));
	}

	/**
	 * 入户走访_人员_暂住人口 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(ryZzrkService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-ryZzrk")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入ryZzrk")
	public void exportRyZzrk(@ApiIgnore @RequestParam Map<String, Object> ryZzrk, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RyZzrkEntity> queryWrapper = Condition.getQueryWrapper(ryZzrk, RyZzrkEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(RyZzrk::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RyZzrkEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RyZzrkExcel> list = ryZzrkService.exportRyZzrk(queryWrapper);
		ExcelUtil.export(response, "入户走访_人员_暂住人口数据" + DateUtil.time(), "入户走访_人员_暂住人口数据表", list, RyZzrkExcel.class);
	}

}
