/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.rule.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.secure.BladeUser;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.DigestUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.byMonth.entity.ByMonthEntity;
import org.springblade.modules.byMonth.service.IByMonthService;
import org.springblade.modules.rule.entity.RuleEntity;
import org.springblade.modules.rule.excel.RuleExcel;
import org.springblade.modules.rule.service.IRuleService;
import org.springblade.modules.rule.vo.RuleVO;
import org.springblade.modules.rule.wrapper.RuleWrapper;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.tool.constant.BladeConstant;
import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

/**
 * sign_rule 控制器
 *
 * @author BladeX
 * @since 2023-07-07
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-rule/rule")
@Api(value = "sign_rule", tags = "sign_rule接口")
public class RuleController extends BladeController {

	private final IRuleService ruleService;

	private final IUserService userService;

	private final IByMonthService byMonthService;

	/**
	 * sign_rule 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入rule")
	public R<RuleVO> detail(RuleEntity rule) {
		RuleEntity detail = ruleService.getOne(Condition.getQueryWrapper(rule));
		return R.data(RuleWrapper.build().entityVO(detail));
	}
	/**
	 * sign_rule 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入rule")
	public R<IPage<RuleVO>> list(@ApiIgnore @RequestParam Map<String, Object> rule, Query query) {
		IPage<RuleEntity> pages = ruleService.page(Condition.getPage(query), Condition.getQueryWrapper(rule, RuleEntity.class));
		return R.data(RuleWrapper.build().pageVO(pages));
	}

	/**
	 * sign_rule 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入rule")
	public R page(Query query) {
		IPage<RuleVO> pages = ruleService.selectRulePage(Condition.getPage(query), AuthUtil.getUserId());
		return R.data(pages);
	}

	/**
	 * sign_rule 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入rule")
	public R save(@Valid @RequestBody RuleEntity rule) {
		return R.status(ruleService.save(rule));
	}

	/**
	 * sign_rule 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入rule")
	public R update(@Valid @RequestBody RuleEntity rule) {
		return R.status(ruleService.updateById(rule));
	}

	/**
	 * sign_rule 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入rule")
	public R submit(@Valid @RequestBody RuleEntity rule) {
		return R.status(ruleService.saveOrUpdate(rule));
	}

	/**
	 * sign_rule 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(ruleService.deleteLogic(Func.toLongList(ids)));
	}


	/**
	 * 导出数据
	 */
	@GetMapping("/export-rule")
	@ApiOperationSupport(order = 9)
	@ApiOperation(value = "导出数据", notes = "传入rule")
	public void exportRule(@ApiIgnore @RequestParam Map<String, Object> rule, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<RuleEntity> queryWrapper = Condition.getQueryWrapper(rule, RuleEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(Rule::getTenantId, bladeUser.getTenantId());
		//}
		queryWrapper.lambda().eq(RuleEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<RuleExcel> list = ruleService.exportRule(queryWrapper);
		ExcelUtil.export(response, "sign_rule数据" + DateUtil.time(), "sign_rule数据表", list, RuleExcel.class);
	}


	@PostMapping("Qr")
	public R Qr(ByMonthEntity byMonth){
		byMonth.setPassword(DigestUtil.encrypt(byMonth.getPassword()));
		User user = userService.getById(AuthUtil.getUserId());
		if (!byMonth.getPassword().equals(user.getPassword())){
			return R.fail("输入的密码跟登陆账号密码不一致，请重新输入");
		}
		return R.data(byMonthService.updateIsconfirm(byMonth));
	}
}
