/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.sqjw.pcsInfo.excel;


import lombok.Data;

import java.util.Date;
import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.excel.annotation.write.style.ColumnWidth;
import com.alibaba.excel.annotation.write.style.ContentRowHeight;
import com.alibaba.excel.annotation.write.style.HeadRowHeight;
import java.io.Serializable;


/**
 * 派出所信息表 Excel实体类
 *
 * @author BladeX
 * @since 2024-01-08
 */
@Data
@ColumnWidth(25)
@HeadRowHeight(20)
@ContentRowHeight(18)
public class PcsInfoExcel implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 公安机关编码
	 */
	@ColumnWidth(20)
	@ExcelProperty("公安机关编码")
	private String gajgbm;
	/**
	 * 公安机关名称
	 */
	@ColumnWidth(20)
	@ExcelProperty("公安机关名称")
	private String gajgmc;
	/**
	 * 机关简称
	 */
	@ColumnWidth(20)
	@ExcelProperty("机关简称")
	private String jgjc;
	/**
	 * 公安机关类别
	 */
	@ColumnWidth(20)
	@ExcelProperty("公安机关类别")
	private String gajglb;
	/**
	 * 公安机关性质
	 */
	@ColumnWidth(20)
	@ExcelProperty("公安机关性质")
	private String gajgxz;
	/**
	 * 公安机关行政区划
	 */
	@ColumnWidth(20)
	@ExcelProperty("公安机关行政区划")
	private String gajgxzqh;
	/**
	 * 人口业务行政区划
	 */
	@ColumnWidth(20)
	@ExcelProperty("人口业务行政区划")
	private String rkywxzqh;
	/**
	 * 所属单位(分局或市局)
	 */
	@ColumnWidth(20)
	@ExcelProperty("所属单位(分局或市局)")
	private String ssdw;
	/**
	 * 公安机关级别
	 */
	@ColumnWidth(20)
	@ExcelProperty("公安机关级别")
	private String gajgjb;
	/**
	 * 编制规格
	 */
	@ColumnWidth(20)
	@ExcelProperty("编制规格")
	private String bzgg;
	/**
	 * 上级统计机关
	 */
	@ColumnWidth(20)
	@ExcelProperty("上级统计机关")
	private String sjtjjg;
	/**
	 * 单位联系电话
	 */
	@ColumnWidth(20)
	@ExcelProperty("单位联系电话")
	private String dwlxdh;
	/**
	 * 派出所码
	 */
	@ColumnWidth(20)
	@ExcelProperty("派出所码")
	private String pcsm;
	/**
	 * 派出所管理类别
	 */
	@ColumnWidth(20)
	@ExcelProperty("派出所管理类别")
	private String pcsgllb;
	/**
	 * 派出所类别
	 */
	@ColumnWidth(20)
	@ExcelProperty("派出所类别")
	private String pcslb;
	/**
	 * 派出所等级
	 */
	@ColumnWidth(20)
	@ExcelProperty("派出所等级")
	private String pcsdj;
	/**
	 * 是否两队一室
	 */
	@ColumnWidth(20)
	@ExcelProperty("是否两队一室 ")
	private Integer ldys;
	/**
	 * 枫桥所情况
	 */
	@ColumnWidth(20)
	@ExcelProperty("枫桥所情况")
	private String fqsqk;
	/**
	 * 辖区面积
	 */
	@ColumnWidth(20)
	@ExcelProperty("辖区面积")
	private String xqmj;
	/**
	 * 社区数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("社区数量")
	private String sqsl;
	/**
	 * 行政村数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("行政村数量")
	private String xzcsl;
	/**
	 * 自然村数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("自然村数量")
	private String zrcsl;
	/**
	 * 网格数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("网格数量")
	private String wgsl;
	/**
	 * 警格数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("警格数量")
	private String jgsl;
	/**
	 * 警务室数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("警务室数量")
	private String jwssl;
	/**
	 * 警务站数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("警务站数量")
	private String jwzsl;
	/**
	 * 户籍人口数量
	 */
	@ColumnWidth(20)
	@ExcelProperty("户籍人口数量")
	private String hjrksl;
	/**
	 * 实有人口数
	 */
	@ColumnWidth(20)
	@ExcelProperty("实有人口数")
	private String syrks;
	/**
	 * 实有户数
	 */
	@ColumnWidth(20)
	@ExcelProperty("实有户数")
	private String syhs;
	/**
	 * 负责人(所长)
	 */
	@ColumnWidth(20)
	@ExcelProperty("负责人(所长)")
	private String fzr;
	/**
	 * 定编民警人数
	 */
	@ColumnWidth(20)
	@ExcelProperty("定编民警人数")
	private String dbmjrs;
	/**
	 * 实有民警人数(不含下派)
	 */
	@ColumnWidth(20)
	@ExcelProperty("实有民警人数(不含下派)")
	private String symjrs;
	/**
	 * 下派民警人数
	 */
	@ColumnWidth(20)
	@ExcelProperty("下派民警人数")
	private String xpmjrs;
	/**
	 * 社区(包村)民警人数
	 */
	@ColumnWidth(20)
	@ExcelProperty("社区(包村)民警人数")
	private String sqmjrs;
	/**
	 * 专职辅警人数
	 */
	@ColumnWidth(20)
	@ExcelProperty("专职辅警人数")
	private String zzfjrs;
	/**
	 * 警务助理人数
	 */
	@ColumnWidth(20)
	@ExcelProperty("警务助理人数")
	private String jwzlrs;
	/**
	 * 办公地址
	 */
	@ColumnWidth(20)
	@ExcelProperty("办公地址")
	private String bgdz;
	/**
	 * 单位地址经度
	 */
	@ColumnWidth(20)
	@ExcelProperty("单位地址经度")
	private String dwdzjd;
	/**
	 * 单位地址纬度
	 */
	@ColumnWidth(20)
	@ExcelProperty("单位地址纬度")
	private String dwdzwd;
	/**
	 * 派出所照片
	 */
	@ColumnWidth(20)
	@ExcelProperty("派出所照片")
	private String pcszp;

}
