package org.springblade.modules.sqmy.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.RoleConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.sqmy.excel.FzrhyInfoExcel;
import org.springblade.modules.sqmy.pojo.entity.FzrhyInfoEntity;
import org.springblade.modules.sqmy.pojo.entity.FzrhyRyEntity;
import org.springblade.modules.sqmy.pojo.entity.JmhRyEntity;
import org.springblade.modules.sqmy.pojo.vo.FzrhyInfoVO;
import org.springblade.modules.sqmy.service.IFzrhyInfoService;
import org.springblade.modules.sqmy.service.IFzrhyRyService;
import org.springblade.modules.sqmy.wrapper.FzrhyInfoWrapper;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 每月安全负责人会议 控制器
 *
 * @author wth
 * @since 2024-11-12
 */
@RestController
@AllArgsConstructor
@RequestMapping("/fzrhyInfo")
@Api(value = "每月安全负责人会议", tags = "每月安全负责人会议接口")
public class FzrhyInfoController extends BladeController {

	private final IFzrhyInfoService fzrhyInfoService;

	private final IFzrhyRyService fzrhyRyService;

	/**
	 * 每月安全负责人会议 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入fzrhyInfo")
	public R<FzrhyInfoVO> detail(FzrhyInfoEntity fzrhyInfo) {
		FzrhyInfoEntity detail = fzrhyInfoService.getOne(Condition.getQueryWrapper(fzrhyInfo));
		List<FzrhyRyEntity> fzrhyRy = fzrhyInfoService.selectFzrhyRy(detail.getId());
		detail.setFzrhyRyList(fzrhyRy);
		return R.data(FzrhyInfoWrapper.build().entityVO(detail));
	}

	/**
	 * 每月安全负责人会议 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入fzrhyInfo")
	public R<IPage<FzrhyInfoVO>> list(@RequestParam Map<String, Object> fzrhyInfo, Query query) {
		IPage<FzrhyInfoEntity> pages = fzrhyInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(fzrhyInfo, FzrhyInfoEntity.class));
		return R.data(FzrhyInfoWrapper.build().pageVO(pages));
	}

	/**
	 * 每月安全负责人会议 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入fzrhyInfo")
	public R<IPage<FzrhyInfoVO>> page(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		IPage<FzrhyInfoVO> pages = fzrhyInfoService.selectFzrhyInfoPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 每月安全负责人会议 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入fzrhyInfo")
	public R save(@Valid @RequestBody FzrhyInfoEntity fzrhyInfo) {
		fzrhyInfoService.save(fzrhyInfo);
		if (null != fzrhyInfo.getFzrhyRyList() && fzrhyInfo.getFzrhyRyList().size() > 0) {
			for (FzrhyRyEntity fzrhyRyEntity : fzrhyInfo.getFzrhyRyList()) {
				fzrhyRyEntity.setFzrhyId(fzrhyInfo.getId());
				fzrhyRyService.save(fzrhyRyEntity);
			}
		}
		return R.status(true);
	}

	/**
	 * 每月安全负责人会议 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入fzrhyInfo")
	public R update(@Valid @RequestBody FzrhyInfoEntity fzrhyInfo) {
		fzrhyInfoService.updateById(fzrhyInfo);
		if (null != fzrhyInfo.getFzrhyRyList() && fzrhyInfo.getFzrhyRyList().size() > 0) {
			for (FzrhyRyEntity fzrhyRyEntity : fzrhyInfo.getFzrhyRyList()) {
				if (null != fzrhyRyEntity.getIsDeleted() && fzrhyRyEntity.getIsDeleted() == 1) {
					fzrhyRyService.removeById(fzrhyRyEntity.getId());
				} else {
					fzrhyRyEntity.setFzrhyId(fzrhyInfo.getId());
					fzrhyRyService.saveOrUpdate(fzrhyRyEntity);
				}
			}
		}
		return R.status(true);
	}

	/**
	 * 每月安全负责人会议 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入fzrhyInfo")
	public R submit(@Valid @RequestBody FzrhyInfoEntity fzrhyInfo) {
		return R.status(fzrhyInfoService.saveOrUpdate(fzrhyInfo));
	}

	/**
	 * 每月安全负责人会议 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@RequestParam String id) {
		return R.status(fzrhyInfoService.deleteLogic(Func.toLongList(id)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-fzrhyInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "导出数据", notes = "传入fzrhyInfo")
	public void exportFzrhyInfo(@RequestParam Map<String, Object> fzrhyInfo, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<FzrhyInfoEntity> queryWrapper = Condition.getQueryWrapper(fzrhyInfo, FzrhyInfoEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(FzrhyInfoEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(FzrhyInfoEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<FzrhyInfoExcel> list = fzrhyInfoService.exportFzrhyInfo(queryWrapper);
		ExcelUtil.export(response, "每月安全负责人会议数据" + DateUtil.time(), "每月安全负责人会议数据表", list, FzrhyInfoExcel.class);
	}
}
