package org.springblade.modules.sqmy.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.RoleConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.sqmy.excel.JmhRyExcel;
import org.springblade.modules.sqmy.pojo.entity.JmhRyEntity;
import org.springblade.modules.sqmy.pojo.vo.JmhRyVO;
import org.springblade.modules.sqmy.service.IJmhRyService;
import org.springblade.modules.sqmy.wrapper.JmhRyWrapper;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 每周见面会_参会人员 控制器
 *
 * @author wth
 * @since 2024-11-12
 */
@RestController
@AllArgsConstructor
@RequestMapping("/jmhRy")
@Api(value = "每周见面会_参会人员", tags = "每周见面会_参会人员接口")
public class JmhRyController extends BladeController {

	private final IJmhRyService jmhRyService;

	/**
	 * 每周见面会_参会人员 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes  = "传入jmhRy")
	public R<JmhRyVO> detail(JmhRyEntity jmhRy) {
		JmhRyEntity detail = jmhRyService.getOne(Condition.getQueryWrapper(jmhRy));
		return R.data(JmhRyWrapper.build().entityVO(detail));
	}

	/**
	 * 每周见面会_参会人员 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes  = "传入jmhRy")
	public R<IPage<JmhRyVO>> list(@RequestParam Map<String, Object> jmhRy, Query query) {
		IPage<JmhRyEntity> pages = jmhRyService.page(Condition.getPage(query), Condition.getQueryWrapper(jmhRy, JmhRyEntity.class));
		return R.data(JmhRyWrapper.build().pageVO(pages));
	}


	/**
	 * 每周见面会_参会人员 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes  = "传入jmhRy")
	public R<IPage<JmhRyVO>> page(JmhRyVO jmhRy, Query query) {
		IPage<JmhRyVO> pages = jmhRyService.selectJmhRyPage(Condition.getPage(query), jmhRy);
		return R.data(pages);
	}

	/**
	 * 每周见面会_参会人员 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes  = "传入jmhRy")
	public R save(@Valid @RequestBody JmhRyEntity jmhRy) {
		return R.status(jmhRyService.save(jmhRy));
	}

	/**
	 * 每周见面会_参会人员 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes  = "传入jmhRy")
	public R update(@Valid @RequestBody JmhRyEntity jmhRy) {
		return R.status(jmhRyService.updateById(jmhRy));
	}

	/**
	 * 每周见面会_参会人员 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes  = "传入jmhRy")
	public R submit(@Valid @RequestBody JmhRyEntity jmhRy) {
		return R.status(jmhRyService.saveOrUpdate(jmhRy));
	}

	/**
	 * 每周见面会_参会人员 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes  = "传入ids")
	public R remove(@RequestParam String ids) {
		return R.status(jmhRyService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-jmhRy")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "导出数据", notes  = "传入jmhRy")
	public void exportJmhRy(@RequestParam Map<String, Object> jmhRy, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<JmhRyEntity> queryWrapper = Condition.getQueryWrapper(jmhRy, JmhRyEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(JmhRyEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(JmhRyEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<JmhRyExcel> list = jmhRyService.exportJmhRy(queryWrapper);
		ExcelUtil.export(response, "每周见面会_参会人员数据" + DateUtil.time(), "每周见面会_参会人员数据表", list, JmhRyExcel.class);
	}

}
