package org.springblade.modules.sqmy.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.RoleConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.sqmy.excel.SqmyRyExcel;
import org.springblade.modules.sqmy.pojo.entity.SqmyRyEntity;
import org.springblade.modules.sqmy.pojo.vo.SqmyRyVO;
import org.springblade.modules.sqmy.service.ISqmyRyService;
import org.springblade.modules.sqmy.wrapper.SqmyRyWrapper;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 社情民意_线索提供人 控制器
 *
 * @author wth
 * @since 2024-11-12
 */
@RestController
@AllArgsConstructor
@RequestMapping("/sqmyRy")
@Api(value = "社情民意_线索提供人", tags = "社情民意_线索提供人接口")
public class SqmyRyController extends BladeController {

	private final ISqmyRyService sqmyRyService;

	/**
	 * 社情民意_线索提供人 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes  = "传入sqmyRy")
	public R<SqmyRyVO> detail(SqmyRyEntity sqmyRy) {
		SqmyRyEntity detail = sqmyRyService.getOne(Condition.getQueryWrapper(sqmyRy));
		return R.data(SqmyRyWrapper.build().entityVO(detail));
	}

	/**
	 * 社情民意_线索提供人 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes  = "传入sqmyRy")
	public R<IPage<SqmyRyVO>> list(@RequestParam Map<String, Object> sqmyRy, Query query) {
		IPage<SqmyRyEntity> pages = sqmyRyService.page(Condition.getPage(query), Condition.getQueryWrapper(sqmyRy, SqmyRyEntity.class));
		return R.data(SqmyRyWrapper.build().pageVO(pages));
	}


	/**
	 * 社情民意_线索提供人 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes  = "传入sqmyRy")
	public R<IPage<SqmyRyVO>> page(SqmyRyVO sqmyRy, Query query) {
		IPage<SqmyRyVO> pages = sqmyRyService.selectSqmyRyPage(Condition.getPage(query), sqmyRy);
		return R.data(pages);
	}

	/**
	 * 社情民意_线索提供人 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes  = "传入sqmyRy")
	public R save(@Valid @RequestBody SqmyRyEntity sqmyRy) {
		return R.status(sqmyRyService.save(sqmyRy));
	}

	/**
	 * 社情民意_线索提供人 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes  = "传入sqmyRy")
	public R update(@Valid @RequestBody SqmyRyEntity sqmyRy) {
		return R.status(sqmyRyService.updateById(sqmyRy));
	}

	/**
	 * 社情民意_线索提供人 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes  = "传入sqmyRy")
	public R submit(@Valid @RequestBody SqmyRyEntity sqmyRy) {
		return R.status(sqmyRyService.saveOrUpdate(sqmyRy));
	}

	/**
	 * 社情民意_线索提供人 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes  = "传入ids")
	public R remove(@RequestParam String ids) {
		return R.status(sqmyRyService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-sqmyRy")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "导出数据", notes  = "传入sqmyRy")
	public void exportSqmyRy(@RequestParam Map<String, Object> sqmyRy, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<SqmyRyEntity> queryWrapper = Condition.getQueryWrapper(sqmyRy, SqmyRyEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(SqmyRyEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(SqmyRyEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<SqmyRyExcel> list = sqmyRyService.exportSqmyRy(queryWrapper);
		ExcelUtil.export(response, "社情民意_线索提供人数据" + DateUtil.time(), "社情民意_线索提供人数据表", list, SqmyRyExcel.class);
	}

}
