package org.springblade.modules.sqmy.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.excel.util.ExcelUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.BladeUser;
import org.springblade.core.secure.annotation.PreAuth;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.constant.RoleConstant;
import org.springblade.core.tool.utils.DateUtil;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.sqmy.excel.ZatbInfoExcel;
import org.springblade.modules.sqmy.pojo.entity.ZatbInfoEntity;
import org.springblade.modules.sqmy.pojo.vo.ZatbInfoVO;
import org.springblade.modules.sqmy.service.IZatbInfoService;
import org.springblade.modules.sqmy.wrapper.ZatbInfoWrapper;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * 季度治安通报 控制器
 *
 * @author wth
 * @since 2024-11-12
 */
@RestController
@AllArgsConstructor
@RequestMapping("/zatbInfo")
@Api(value = "季度治安通报", tags = "季度治安通报接口")
public class ZatbInfoController extends BladeController {

	private final IZatbInfoService zatbInfoService;

	/**
	 * 季度治安通报 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes  = "传入zatbInfo")
	public R<ZatbInfoVO> detail(ZatbInfoEntity zatbInfo) {
		ZatbInfoEntity detail = zatbInfoService.getOne(Condition.getQueryWrapper(zatbInfo));
		return R.data(ZatbInfoWrapper.build().entityVO(detail));
	}

	/**
	 * 季度治安通报 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes  = "传入zatbInfo")
	public R<IPage<ZatbInfoVO>> list(@RequestParam Map<String, Object> zatbInfo, Query query) {
		IPage<ZatbInfoEntity> pages = zatbInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(zatbInfo, ZatbInfoEntity.class));
		return R.data(ZatbInfoWrapper.build().pageVO(pages));
	}

	/**
	 * 季度治安通报 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes  = "传入zatbInfo")
	public R<IPage<ZatbInfoVO>> page(@RequestParam Map<String, Object> params, Query query) {
		params.put("deptId", AuthUtil.getDeptId());
		IPage<ZatbInfoVO> pages = zatbInfoService.selectZatbInfoPage(Condition.getPage(query), params);
		return R.data(pages);
	}

	/**
	 * 季度治安通报 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes  = "传入zatbInfo")
	public R save(@Valid @RequestBody ZatbInfoEntity zatbInfo) {
		return R.status(zatbInfoService.save(zatbInfo));
	}

	/**
	 * 季度治安通报 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes  = "传入zatbInfo")
	public R update(@Valid @RequestBody ZatbInfoEntity zatbInfo) {
		return R.status(zatbInfoService.updateById(zatbInfo));
	}

	/**
	 * 季度治安通报 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes  = "传入zatbInfo")
	public R submit(@Valid @RequestBody ZatbInfoEntity zatbInfo) {
		return R.status(zatbInfoService.saveOrUpdate(zatbInfo));
	}

	/**
	 * 季度治安通报 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes  = "传入ids")
	public R remove(@RequestParam String ids) {
		return R.status(zatbInfoService.deleteLogic(Func.toLongList(ids)));
	}

	/**
	 * 导出数据
	 */
	@PreAuth(RoleConstant.HAS_ROLE_ADMIN)
	@GetMapping("/export-zatbInfo")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "导出数据", notes  = "传入zatbInfo")
	public void exportZatbInfo(@RequestParam Map<String, Object> zatbInfo, BladeUser bladeUser, HttpServletResponse response) {
		QueryWrapper<ZatbInfoEntity> queryWrapper = Condition.getQueryWrapper(zatbInfo, ZatbInfoEntity.class);
		//if (!AuthUtil.isAdministrator()) {
		//	queryWrapper.lambda().eq(ZatbInfoEntity::getTenantId, bladeUser.getTenantId());
		//}
		//queryWrapper.lambda().eq(ZatbInfoEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
		List<ZatbInfoExcel> list = zatbInfoService.exportZatbInfo(queryWrapper);
		ExcelUtil.export(response, "季度治安通报数据" + DateUtil.time(), "季度治安通报数据表", list, ZatbInfoExcel.class);
	}

}
