package org.springblade.modules.system.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springblade.core.tool.api.R;
import org.springblade.modules.system.entity.Bzdz;
import org.springblade.modules.system.entity.Dept;
import org.springblade.modules.system.excel.DeptExcel;
import org.springblade.modules.system.vo.*;

import java.util.List;
import java.util.Map;

/**
 * 服务类
 *
 * @author Chill
 */
public interface IDeptService extends IService<Dept> {

	/**
	 * 懒加载部门列表
	 *
	 * @param tenantId
	 * @param parentId
	 * @param param
	 * @return
	 */
	List<DeptVO> lazyList(String tenantId, Long parentId, Map<String, Object> param);

	/**
	 * 树形结构
	 *
	 * @param tenantId
	 * @return
	 */
	List<DeptVO> tree(String tenantId, String deptId);

	/**
	 * 懒加载树形结构
	 *
	 * @param tenantId
	 * @param parentId
	 * @return
	 */
	List<DeptVO> lazyTree(String tenantId, Long parentId, String deptId);

	/**
	 * 获取部门ID
	 *
	 * @param tenantId
	 * @param deptNames
	 * @return
	 */
	String getDeptIds(String tenantId, String deptNames);

	/**
	 * 获取部门ID
	 *
	 * @param tenantId
	 * @param deptNames
	 * @return
	 */
	String getDeptIdsByFuzzy(String tenantId, String deptNames);

	/**
	 * 获取部门名
	 *
	 * @param deptIds
	 * @return
	 */
	List<String> getDeptNames(String deptIds);

	/**
	 * 获取子部门ID
	 *
	 * @param deptId
	 * @return
	 */
	List<Dept> getDeptChild(Long deptId);

	/**
	 * 删除部门
	 *
	 * @param ids
	 * @return
	 */
	boolean removeDept(String ids);

	/**
	 * 提交
	 *
	 * @param dept
	 * @return
	 */
	boolean submit(Dept dept);

	/**
	 * 部门信息查询
	 *
	 * @param deptName
	 * @param parentId
	 * @return
	 */
	List<DeptVO> search(String deptName, Long parentId);

	String getDeptIdByDeptname(String deptName);

    List<DeptVO> getXfbm();

    List<DeptListVo> getDeptList(Long userId);

	List<FjVO> getfJList(String deptId);

    List<PcsVO> getPcsList(String deptId, Long fjId);

	List<SqVO> getSqList(String deptId, Long pcsId);

    String selectSq(String deptId);

	String selectPcs(String deptId);

	Dept selectSsfjBm(String ssfjMc);

	Dept selectSspcsBm(String sspcsMc, String ssfjMc);

	Dept selectSssqBm(String sssqMc, Long parentId);

	Long getParentId(DeptExcel deptExcel);

    List<Dept> getJsByFj(String deptId);

	List<Dept> getJsByPcs(Long parentId);

	List<Dept> getJsBySq(Long parentId);

	List<Dept> getJsByFjDownPcs(String value);

	List<Dept> getJsByPcsDownPcs(String deptId);

	List<Dept> getJsBySqDownPcs(Long parentId);

	List<Dept> getJsByFjDownSq(String value);

	List<Dept> getJsByPcsDownSq(String value);

	Dept getJsBySqDownSq(String deptId);

	List<Dept> getJsBySj(String deptId);

    List<Dept> getQsga(String deptId);

	Dept getJxcspc(Long id);

	Dept getJxcsjc(Long id);

	IPage<DeptVOS> getQsyhcsjc(IPage<Object> page, DeptVOS deptVOS);

	List<DeptVOS> getQsyhcsjcfj(String id, String datetime);

	List<Bzdz> getLdByPcsbm(String deptId, String wzxxdz);
	Bzdz getLdInfoByLdbh(String xxzjbh,String deptId);
	void updateSSSqDmByxxzjbh(String xxzjbh,String sqId,String deptId);
	boolean updateSSSqDmIsNUll(String xxzjbh);
	boolean updateSSSqDmIsNUllnew(String dzbm,String sssqBm);
	void deleteByLdId(String id);

	R<String> updateBzdzGlsq(String ldIds, String sqId);

    boolean updateId(Dept dept);

	Dept getDeptCategory(String deptId);

	List<ZdbVo> getShi();
	List<ZdbVo> getXqShiZddm(String shiZddm);
	List<ZdbVo> getJdByXqZddm(String xqZddm);
	List<ZdbVo> getSqByJdZddm(String jdZddm);

	void updateXqParent(String shiZddm);
	void updateJdParent(String xqzddm,String parents);
	void updateSqParent(String jdzddm,String parents);

	MjDeptVO getDeptDetail(String deptId);

	List<Dept> getSqByPcs(MjDeptVO mjDeptVO);

	int countDeptById(Long deptId);

	Long getDeptByQhAndCategory(String xzqh);

    List<ZdVOSS> getDept(String deptId);

	List<ZdldVo> getZdLdBySssqbm(String sssqBm);

	List<ZdVO> getBmByDept(String deptId);

	Bzdz getSssqBmBydzbm(String dzbm);

	boolean updatePlsc(String[] dzbms, String sssqBm);

	List<ZdVO> getDeptNameById(String deptId, Dept byId);

    Dept selectSjByFj(String deptId);

	Dept selectSjByPcs(String deptId);

	Dept selectSjBySqmj(String deptId);

	Dept getParentDept(String deptId);

    boolean getBmxg(Dept dept);

    Dept getFjPcsBySq(Long sssqBm);

	List<FjVOS> getfJLists(String deptId);

	List<PcsVOS> getPcsLists(String deptId, String fjId);

    List<FjVOS> getSfjZdb(String deptId);

	List<PcsVOS> getPcsZdb(String value);

	int getDeptById(Long id);

    List<ZdVO> getPcsByFjId(String deptId);

	boolean updateAncestors(String str, Long id, String ancestors);

	boolean deleteByPcsId(String str);

	Dept getDeptCategoryByAccount(String username);

    Dept getSjByAccount(String deptId);
}
