/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.service;


import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.core.mp.base.BaseService;
import org.springblade.core.mp.support.Query;
import org.springblade.modules.auth.enums.UserEnum;
import org.springblade.modules.fjInfo.entity.FjInfoEntity;
import org.springblade.modules.rk.vo.LbVO;
import org.springblade.modules.system.entity.*;
import org.springblade.modules.system.excel.FjxxExcel;
import org.springblade.modules.system.excel.UserExcel;
import org.springblade.modules.system.excel.UserYhExcel;
import org.springblade.modules.system.vo.*;

import java.util.List;
import java.util.Map;

/**
 * 服务类
 *
 * @author Chill
 */
public interface IUserService extends BaseService<User> {

	/**
	 * 新增用户
	 *
	 * @param user
	 * @return
	 */
	boolean submit(User user);

	/**
	 * 修改用户
	 *
	 * @param user
	 * @return
	 */
	boolean updateUser(User user);

	/**
	 * 修改用户基本信息
	 *
	 * @param user
	 * @return
	 */
	boolean updateUserInfo(User user);

	/**
	 * 自定义分页
	 *
	 * @param page
	 * @param user
	 * @param deptId
	 * @param tenantId
	 * @return
	 */
	IPage<User> selectUserPage(IPage<User> page, User user, String deptId, String tenantId);
	IPage<User> selectUserPage1(IPage<User> page, User user, String deptId, String tenantId);

	/**
	 * 自定义分页
	 *
	 * @param user
	 * @param query
	 * @return
	 */
	IPage<UserVO> selectUserSearch(UserVO user, Query query);

	/**
	 * 根据账号获取用户
	 *
	 * @param tenantId
	 * @param account
	 * @return
	 */
	User userByAccount(String tenantId, String account);

	/**
	 * 用户信息
	 *
	 * @param userId
	 * @return
	 */
	UserInfo userInfo(Long userId);

	/**
	 * 用户信息
	 *
	 * @param tenantId
	 * @param account
	 * @param password
	 * @return
	 */
	UserInfo userInfo(String tenantId, String account, String password);

	/**
	 * 用户信息
	 *
	 * @param tenantId
	 * @param account
	 * @param password
	 * @param userEnum
	 * @return
	 */
	UserInfo userInfo(String tenantId, String account, String password, UserEnum userEnum);

	/**
	 * 用户信息
	 *
	 * @param userOauth
	 * @return
	 */
	UserInfo userInfo(UserOauth userOauth);

	/**
	 * 给用户设置角色
	 *
	 * @param userIds
	 * @param roleIds
	 * @return
	 */
	boolean grant(String userIds, String roleIds);

	/**
	 * 初始化密码
	 *
	 * @param userIds
	 * @return
	 */
	boolean resetPassword(String userIds);

	/**
	 * 修改密码
	 *
	 * @param userId
	 * @param oldPassword
	 * @param newPassword
	 * @param newPassword1
	 * @return
	 */
	boolean updatePassword(Long userId, String oldPassword, String newPassword, String newPassword1);

	/**
	 * 删除用户
	 *
	 * @param userIds
	 * @return
	 */
	boolean removeUser(String userIds);

	/**
	 * 导入用户数据
	 *
	 * @param data
	 * @param isCovered
	 * @return
	 */
	void importUser(List<UserExcel> data, Boolean isCovered);

	/**
	 * 导出用户数据
	 *
	 * @param queryWrapper
	 * @return
	 */
	List<UserExcel> exportUser(Wrapper<User> queryWrapper);

	/**
	 * 注册用户
	 *
	 * @param user
	 * @param oauthId
	 * @return
	 */
	boolean registerGuest(User user, Long oauthId);

	/**
	 * 配置用户平台
	 *
	 * @param userId
	 * @param userType
	 * @param userExt
	 * @return
	 */
	boolean updatePlatform(Long userId, Integer userType, String userExt);

	/**
	 * 用户详细信息
	 *
	 * @param user
	 * @return
	 */
	UserVO platformDetail(User user);

    String getCodeByUsername(String username);

	String getUsernameByCode(String code);

	void updateCode(String username, String code);

    User selectUserIdByPhone(String xpmjlxdh);

    User selectUser(Long userId);

	List<LbVO> selectSq(Long userId);

    List<UserVO> getMjList(Map<String, Object> params);

    String getUsernameBySfzh(String sfzh);

	String getRoleId(String roleName);

	String getSqId(String sqName, String pcsName, Long fjId);

	String getPcsId(String pcsName, Long fjId);

	List<User> getUserList();

	void updateSfzh(User user);

	String getRoleName(String username);

	User getById(Long userId);

    void updateLastLoginTime(String username);

	String getZxxdSqId(String pcsDm);

	Long getIdByAccount(String account);

	User getUserNameById(Long createUser);

    boolean updateDeptId(Long userId, String ids);

	String getPcsIdByPcsName(String pcsName, int deptCategory);

	SyBottomVO getSyBottom(String deptId);

	SyCenterVO getSyCenter(String deptId);

	SyCenterVO getSyCenterzs();

	SyTopVO getSyTop(String dept);

    User getByName(String cjr);

	User selectAccountByUserName(String username);

    PhVO getSyCenterPh(String deptId, String dept);

    List<GsdrsjbVO> getGsdrsjb(GsdrsjbVO gsdrsjbVO);

	List<UserYhExcel> getYhByCreateTime(User user);

    boolean qcCode(String id);

    int getFjsl(Long id);

	String getPhone(Long id);

	Integer getPhoneXz(String phone);

    IPage<User> getFjgl(IPage<Object> page, User user);

	List<ZdVO> getPcsFj(Dept dept);

	boolean updateFj(FjInfoEntity fjInfo, Long mjid);

	boolean updateUserFj(User user);

	List<FjInfoEntity> getFj(Long id);

	boolean deleteFj(Long id);

	List<FjxxExcel> exportFjxx(Map<String, Object> params);

    User selectMj(Long id);

	User selectMjPcs(Long id);

	void updateStatus();

	void zx(User oldUser);

	Integer getFwzs(String deptId);

	Integer getSydwzs(String deptId);

	Integer getCzrk(String deptId);

	Integer getJzrk(String deptId);

	Integer getZzrk(String deptId);

	Integer getJwrk(String deptId);

	Integer getWlrk(String deptId);

	Integer getSwzdrzs(String deptId);

	Integer getTddxzs(String deptId);

	Integer getMdjfzs(String deptId);

	Integer getJxcszs(String deptId);

	RkxxEntity selectRyxxBySfzh(String sfzh);
}
