/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springblade.common.cache.DictBizCache;
import org.springblade.common.constant.CommonConstant;
import org.springblade.core.cache.utils.CacheUtil;
import org.springblade.core.log.exception.ServiceException;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.constant.BladeConstant;
import org.springblade.core.tool.node.ForestNodeMerger;
import org.springblade.core.tool.utils.Func;
import org.springblade.core.tool.utils.StringPool;
import org.springblade.modules.gzInfo.vo.ZdVo;
import org.springblade.modules.gzInfo.vo.ZdVos;
import org.springblade.modules.gzInfo.vo.ZdVoss;
import org.springblade.modules.sqjw.sydw.pojo.vo.HylxVO;
import org.springblade.modules.system.entity.DictBiz;
import org.springblade.modules.system.mapper.DictBizMapper;
import org.springblade.modules.system.service.IDictBizService;
import org.springblade.modules.system.vo.DictBizVO;
import org.springblade.modules.system.vo.ZdVO;
import org.springblade.modules.system.wrapper.DictBizWrapper;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import static org.springblade.core.cache.constant.CacheConstant.DICT_CACHE;

/**
 * 服务实现类
 *
 * @author Chill
 */
@Service
public class DictBizServiceImpl extends ServiceImpl<DictBizMapper, DictBiz> implements IDictBizService {

	@Override
	public List<DictBizVO> tree() {
		return ForestNodeMerger.merge(baseMapper.tree());
	}

	@Override
	public List<DictBizVO> parentTree() {
		return ForestNodeMerger.merge(baseMapper.parentTree());
	}

	@Override
	public String getValue(String code, String dictKey) {
		return Func.toStr(baseMapper.getValue(code, dictKey), StringPool.EMPTY);
	}

	@Override
	public String getKey(String code, String dictValue) {
		return Func.toStr(baseMapper.getKey(code, dictValue), StringPool.EMPTY);
	}

	@Override
	public List<DictBiz> getList(String code) {
		return baseMapper.getList(code);
	}
	@Override
	public List<DictBiz> getListPC(String code) {
		return baseMapper.getListPC(code);
	}

	@Override
	public boolean submit(DictBiz dict) {
		LambdaQueryWrapper<DictBiz> lqw = Wrappers.<DictBiz>query().lambda().eq(DictBiz::getCode, dict.getCode()).eq(DictBiz::getDictKey, dict.getDictKey());
		Long cnt = baseMapper.selectCount((Func.isEmpty(dict.getId())) ? lqw : lqw.notIn(DictBiz::getId, dict.getId()));
		if (cnt > 0L) {
			throw new ServiceException("当前字典键值已存在!");
		}
		// 修改顶级字典后同步更新下属字典的编号
		if (Func.isNotEmpty(dict.getId()) && dict.getParentId().longValue() == BladeConstant.TOP_PARENT_ID) {
			DictBiz parent = DictBizCache.getById(dict.getId());
			this.update(Wrappers.<DictBiz>update().lambda().set(DictBiz::getCode, dict.getCode()).eq(DictBiz::getCode, parent.getCode()).ne(DictBiz::getParentId, BladeConstant.TOP_PARENT_ID));
		}
		if (Func.isEmpty(dict.getParentId())) {
			dict.setParentId(BladeConstant.TOP_PARENT_ID);
		}
		dict.setIsDeleted(BladeConstant.DB_NOT_DELETED);
		CacheUtil.clear(DICT_CACHE);
		return saveOrUpdate(dict);
	}

	@Override
	public boolean removeDict(String ids) {
		Long cnt = baseMapper.selectCount(Wrappers.<DictBiz>query().lambda().in(DictBiz::getParentId, Func.toLongList(ids)));
		if (cnt > 0L) {
			throw new ServiceException("请先删除子节点!");
		}
		return removeByIds(Func.toLongList(ids));
	}

	@Override
	public IPage<DictBizVO> parentList(Map<String, Object> dict, Query query) {
		IPage<DictBiz> page = this.page(Condition.getPage(query), Condition.getQueryWrapper(dict, DictBiz.class).lambda().eq(DictBiz::getParentId, CommonConstant.TOP_PARENT_ID).orderByAsc(DictBiz::getSort));
		return DictBizWrapper.build().pageVO(page);
	}

	@Override
	public List<DictBizVO> childList(Map<String, Object> dict, Long parentId) {
		if (parentId < 0) {
			return new ArrayList<>();
		}
		dict.remove("parentId");
		DictBiz parentDict = DictBizCache.getById(parentId);
		List<DictBiz> list = this.list(Condition.getQueryWrapper(dict, DictBiz.class).lambda().ne(DictBiz::getId, parentId).eq(DictBiz::getCode, parentDict.getCode()).orderByAsc(DictBiz::getSort));
		return DictBizWrapper.build().listNodeVO(list);
	}

	@Override
	public List<ZdVo> selectGzlx(int type) {
		return baseMapper.selectGzlx(type);
	}

	@Override
	public List<ZdVos> selectGzlxs(Long id, int type) {
		return baseMapper.selectGzlxs(id, type);
	}

	@Override
	public List<ZdVoss> selectGzlxss(Long id, int type) {
		return baseMapper.selectGzlxss(id, type);
	}

	@Override
	public List<ZdVO> getJxcs() {
		return baseMapper.getJxcs();
	}

	@Override
	public List<ZdVO> csxl(ZdVO zdVO) {
		return baseMapper.csxl(zdVO);
	}

	@Override
	public List<ZdVo> selectJflx(Map<String, Object> params) {
		return baseMapper.selectJflx(params);
	}

	@Override
	public List<ZdVo> selectJflx2(Map<String, Object> params) {
		return baseMapper.selectJflx2(params);
	}

	@Override
	public List<ZdVos> getXmList(Map<String, Object> params) {
		return baseMapper.getXmList(params);
	}

	@Override
	public List<ZdVoss> getXmList2(Long parentId) {
		return baseMapper.getXmList2(parentId);
	}

	@Override
	public String selectDwlb() {
		List<DictBiz> strings = baseMapper.selectDwlb();
		String s = new String();
		for (DictBiz d:strings){
			s += d.getDictValue();
			s += ",";
		}
		return s.substring(0, s.length() - 1);
	}

	@Override
	public List<ZdVO> getDictList(String code) {
		return baseMapper.getDictList(code);
	}

	@Override
	public List<ZdVO> getLdphhz(Map<String, String> params) {
		return baseMapper.getLdphhz(params);
	}

	@Override
	public int getZfcs() {
		return baseMapper.getZfcs();
	}

	@Override
	public int getFjsl() {
		return baseMapper.getFjsl();
	}

	@Override
	public int getKfsl() {
		return baseMapper.getKfsl();
	}

	@Override
	public List<ZdVO> getTsrq() {
		return baseMapper.getTsrq();
	}

	@Override
	public List<HylxVO> getHylx() {
		return baseMapper.getHylx();
	}

	@Override
	public List<ZdVO> getDwlx(Long parentId) {
		return baseMapper.getDwlx(parentId);
	}
}
