/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.zdb.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.apache.commons.lang3.StringUtils;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;

import org.springblade.modules.zdb.vo.XqVo;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.zdb.entity.ZdbEntity;
import org.springblade.modules.zdb.vo.ZdbVO;
import org.springblade.modules.zdb.wrapper.ZdbWrapper;
import org.springblade.modules.zdb.service.IZdbService;
import org.springblade.core.boot.ctrl.BladeController;

import springfox.documentation.annotations.ApiIgnore;
import java.util.Map;


/**
 * 字典表 控制器
 *
 * @author BladeX
 * @since 2023-12-28
 */
@RestController
@AllArgsConstructor
@RequestMapping("blade-zdb/zdb")
@Api(value = "字典表", tags = "字典表接口")
public class ZdbController extends BladeController {

	private final IZdbService zdbService;

	/**
	 * 字典表 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入zdb")
	public R<ZdbVO> detail(ZdbEntity zdb) {
		ZdbEntity detail = zdbService.getOne(Condition.getQueryWrapper(zdb));
		return R.data(ZdbWrapper.build().entityVO(detail));
	}
	/**
	 * 字典表 分页
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入zdb")
	public R<IPage<ZdbVO>> list(@ApiIgnore @RequestParam Map<String, Object> zdb, Query query) {
		IPage<ZdbEntity> pages = zdbService.page(Condition.getPage(query), Condition.getQueryWrapper(zdb, ZdbEntity.class));
		return R.data(ZdbWrapper.build().pageVO(pages));
	}

	/**
	 * 字典表 自定义分页
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入zdb")
	public R<IPage<ZdbVO>> page(ZdbVO zdb, Query query) {
		IPage<ZdbVO> pages = zdbService.selectZdbPage(Condition.getPage(query), zdb);
		return R.data(pages);
	}

	/**
	 * 字典表 新增
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入zdb")
	public R save(@Valid @RequestBody ZdbEntity zdb) {
		//创建行政区划    组成：pcsid前6位 第七位：新增时 值为9
		String xzqh = "";
		if(StringUtils.isNotBlank(zdb.getParentId())){
			//获取parentid  截取前6位
			xzqh = zdb.getParentId().substring(0,6);
			zdb.setZddm(xzqh+"9"+"1");
		}

		return R.status(zdbService.save(zdb));
	}
	/**
	 * 字典表 修改
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入zdb")
	public R update(@Valid @RequestBody ZdbEntity zdb) {
		return R.status(zdbService.updateById(zdb));
	}

	/**
	 * 字典表 新增或修改
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入zdb")
	public R submit(@Valid @RequestBody ZdbEntity zdb) {
		return R.status(zdbService.saveOrUpdate(zdb));
	}

	/**
	 * 字典表 删除
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(zdbService.deleteLogic(Func.toLongList(ids)));
	}


//	/**
//	 * 导出数据
//	 */
//	@GetMapping("/export-zdb")
//	@ApiOperationSupport(order = 9)
//	@ApiOperation(value = "导出数据", notes = "传入zdb")
//	public void exportZdb(@ApiIgnore @RequestParam Map<String, Object> zdb, BladeUser bladeUser, HttpServletResponse response) {
//		QueryWrapper<ZdbEntity> queryWrapper = Condition.getQueryWrapper(zdb, ZdbEntity.class);
//		//if (!AuthUtil.isAdministrator()) {
//		//	queryWrapper.lambda().eq(Zdb::getTenantId, bladeUser.getTenantId());
//		//}
//		queryWrapper.lambda().eq(ZdbEntity::getIsDeleted, BladeConstant.DB_NOT_DELETED);
//		List<ZdbExcel> list = zdbService.exportZdb(queryWrapper);
//		ExcelUtil.export(response, "字典表数据" + DateUtil.time(), "字典表数据表", list, ZdbExcel.class);
//	}

	/**
	 * 获取子类
	 */
	@GetMapping("/getChildrenByZddm")
	@ApiOperationSupport(order = 10)
	@ApiOperation(value = "查询子类", notes = "传入zddm")
	public R<XqVo> getChildrenByZddm(@RequestParam String zddm) {
		return R.data(zdbService.getChildrenByZddm(zddm));
	}

	/**
	 * 获取父类
	 */
	@GetMapping("/getParentsBySqbm")
	@ApiOperationSupport(order = 11)
	@ApiOperation(value = "查询父类", notes = "传入zddm")
	public R getParentsBySqbm(@RequestParam String zddm) {
		ZdbEntity deptByZddm = zdbService.getDeptByZddm(zddm);
		if(deptByZddm != null && "5".equals(deptByZddm.getLb())){
			if(deptByZddm.getParents().split(",").length == 5 ){
				return R.data(zdbService.getParentsBySqbm(zddm));
			}
		}
		return R.fail(505,"该社区机构不准确，请联系管理员");
	}
	/**
	 * 获取父类
	 */
	@GetMapping("/getDetailByZddm")
	@ApiOperationSupport(order = 12)
	@ApiOperation(value = "查询父类", notes = "传入zddm")
	public R<ZdbEntity> getDetailByZddm(@RequestParam String zddm) {
		return R.data(zdbService.getDetailByZddm(zddm));
	}
}
